@@ -27,11 +27,12 @@
 #include "iproject.h"
 
 #include <QtDBus/QtDBus>
-#include <language/duchain/indexedstring.h>
 
 namespace KDevelop
 {
 
+class Path;
+
 IProject::IProject(QObject *parent)
     : QObject(parent)
 {
@@ -43,4 +44,3 @@ IProject::~IProject()
 
 }
 
-#include "iproject.moc"
