@@ -100,7 +100,7 @@ inline bool isValidURL(const IndexedString& url)
         return false;
     }
     QUrl original = url.toUrl();
-    if (!original.isValid() || original.isRelative() || (original.fileName().isEmpty() && original.isLocalFile())) {
+    if (!original.isValid() || original.isRelative() || original.fileName().isEmpty()) {
         qCWarning(LANGUAGE) << "INVALID URL ENCOUNTERED:" << url << original;
         return false;
     }
@@ -816,7 +816,7 @@ DocumentChangeTracker* BackgroundParser::trackerForUrl(const KDevelop::IndexedSt
     if (url.isEmpty()) {
         // this happens e.g. when setting the final location of a problem that is not
         // yet associated with a top ctx.
-        return 0;
+        return nullptr;
     }
     if ( !isValidURL(url) ) {
         qWarning() << "Tracker requested for invalild URL:" << url.toUrl();
@@ -824,7 +824,7 @@ DocumentChangeTracker* BackgroundParser::trackerForUrl(const KDevelop::IndexedSt
     Q_ASSERT(isValidURL(url));
 
     QMutexLocker l(&d->m_managedMutex);
-    return d->m_managed.value(url, 0);
+    return d->m_managed.value(url, nullptr);
 }
 
 void BackgroundParser::documentClosed(IDocument* document)
