@@ -26,7 +26,6 @@
 #include <QByteArray>
 #include <QMutex>
 #include <QMutexLocker>
-#include <threadweaver/qobjectdecorator.h>
 #include <QApplication>
 #include <QDebug>
 
@@ -99,14 +98,12 @@ public:
 
     int parsePriority;
     ParseJob::SequentialProcessingFlags sequentialProcessingFlags;
-    ThreadWeaver::QObjectDecorator* decorator;
 };
 
 ParseJob::ParseJob( const IndexedString& url, KDevelop::ILanguageSupport* languageSupport )
         : ThreadWeaver::Sequence(),
         d(new ParseJobPrivate(url, languageSupport))
 {
-    d->decorator = new ThreadWeaver::QObjectDecorator(this);
 }
 
 ParseJob::~ParseJob()
@@ -169,7 +166,7 @@ void ParseJob::setMinimumFeatures(TopDUContext::Features features)
 bool ParseJob::hasStaticMinimumFeatures()
 {
     QMutexLocker lock(&minimumFeaturesMutex);
-    return ::staticMinimumFeatures.size();
+    return !::staticMinimumFeatures.isEmpty();
 }
 
 TopDUContext::Features ParseJob::staticMinimumFeatures(const IndexedString& url)
@@ -178,7 +175,7 @@ TopDUContext::Features ParseJob::staticMinimumFeatures(const IndexedString& url)
     TopDUContext::Features features = (TopDUContext::Features)0;
 
     if(::staticMinimumFeatures.contains(url))
-        foreach(const TopDUContext::Features &f, ::staticMinimumFeatures[url])
+        foreach(const TopDUContext::Features f, ::staticMinimumFeatures[url])
             features = (TopDUContext::Features)(features | f);
 
     return features;
@@ -336,7 +333,7 @@ struct MovingRangeTranslator : public DUChainVisitor
     MovingRangeTranslator(qint64 _source, qint64 _target, MovingInterface* _moving) : source(_source), target(_target), moving(_moving) {
     }
 
-    virtual void visit(DUContext* context) override {
+    void visit(DUContext* context) override {
         translateRange(context);
         ///@todo Also map import-positions
         // Translate uses
@@ -349,7 +346,7 @@ struct MovingRangeTranslator : public DUChainVisitor
         }
     }
 
-    virtual void visit(Declaration* declaration) override {
+    void visit(Declaration* declaration) override {
         translateRange(declaration);
     }
 
@@ -520,10 +517,5 @@ bool ParseJob::hasTracker() const
     return d->tracker;
 }
 
-ThreadWeaver::QObjectDecorator* ParseJob::decorator() const
-{
-    return d->decorator;
-}
-
 }
 
