@@ -43,7 +43,7 @@ struct CompletionTreeNode;
 ///Leaf items
 class CompletionTreeItem;
 
-CompletionTreeElement::CompletionTreeElement() : m_parent(0), m_rowInParent(0) {
+CompletionTreeElement::CompletionTreeElement() : m_parent(nullptr), m_rowInParent(0) {
 }
 
 CompletionTreeElement::~CompletionTreeElement() {
@@ -54,11 +54,11 @@ CompletionTreeElement* CompletionTreeElement::parent() const {
 }
 
 void CompletionTreeElement::setParent(CompletionTreeElement* parent) {
-    Q_ASSERT(m_parent == 0);
+    Q_ASSERT(m_parent == nullptr);
 
     m_parent = parent;
-    CompletionTreeNode* node = parent->asNode();
-    if( node ) {
+    auto node = parent ? parent->asNode() : nullptr;
+    if (node) {
       m_rowInParent = node->children.count();
     }
 }
@@ -84,8 +84,9 @@ int CompletionTreeElement::columnInParent() const {
   return 0;
 }
 
-CompletionTreeNode::CompletionTreeNode() : CompletionTreeElement() {
-}
+CompletionTreeNode::CompletionTreeNode() : CompletionTreeElement(), role((KTextEditor::CodeCompletionModel::ExtraItemDataRoles)Qt::DisplayRole)
+{}
+
 CompletionTreeNode::~CompletionTreeNode() {
 }
 
