@@ -54,6 +54,7 @@ REGISTER_DUCHAIN_ITEM(Declaration);
 
 DeclarationData::DeclarationData()
   : m_comment(0)
+  , m_kind(Declaration::Instance)
   , m_isDefinition(false)
   , m_inSymbolTable(false)
   , m_isTypeAlias(false)
@@ -63,7 +64,6 @@ DeclarationData::DeclarationData()
   , m_isAutoDeclaration(false)
   , m_isExplicitlyDeleted(false)
 {
-  m_kind = Declaration::Instance;
 }
 
 DeclarationData::DeclarationData( const DeclarationData& rhs ) : DUChainBaseData(rhs),
@@ -119,8 +119,8 @@ Declaration::Declaration( const RangeInRevision& range, DUContext* context )
   : DUChainBase(*new DeclarationData, range)
 {
   d_func_dynamic()->setClassId(this);
-  m_topContext = 0;
-  m_context = 0;
+  m_topContext = nullptr;
+  m_context = nullptr;
   m_indexInTopContext = 0;
 
   if(context)
@@ -135,23 +135,23 @@ uint Declaration::ownIndex() const
 
 Declaration::Declaration(const Declaration& rhs)
   : DUChainBase(*new DeclarationData( *rhs.d_func() )) {
-  m_topContext = 0;
-  m_context = 0;
+  m_topContext = nullptr;
+  m_context = nullptr;
   m_indexInTopContext = 0;
 }
 
 Declaration::Declaration( DeclarationData & dd ) : DUChainBase(dd)
 {
-  m_topContext = 0;
-  m_context = 0;
+  m_topContext = nullptr;
+  m_context = nullptr;
   m_indexInTopContext = 0;
 }
 
 Declaration::Declaration( DeclarationData & dd, const RangeInRevision& range )
   : DUChainBase(dd, range)
 {
-  m_topContext = 0;
-  m_context = 0;
+  m_topContext = nullptr;
+  m_context = nullptr;
   m_indexInTopContext = 0;
 }
 
@@ -173,7 +173,7 @@ Declaration::~Declaration()
 
     // Inserted by the builder after construction has finished.
     if( d->m_internalContext.context() )
-      d->m_internalContext.context()->setOwner(0);
+      d->m_internalContext.context()->setOwner(nullptr);
 
     setInSymbolTable(false);
   }
@@ -188,7 +188,7 @@ Declaration::~Declaration()
   clearOwnIndex();
 
   if(!topContext->deleting() || !topContext->isOnDisk()) {
-    setContext(0);
+    setContext(nullptr);
 
     setAbstractType(AbstractType::Ptr());
   }
@@ -199,7 +199,7 @@ Declaration::~Declaration()
 QByteArray Declaration::comment() const {
   DUCHAIN_D(Declaration);
   if(!d->m_comment)
-    return 0;
+    return nullptr;
   else
     return Repositories::arrayFromItem(commentRepository().itemFromIndex(d->m_comment));
 }
@@ -266,7 +266,7 @@ void Declaration::setAbstractType(AbstractType::Ptr type)
   ENSURE_CAN_WRITE
   DUCHAIN_D_DYNAMIC(Declaration);
 
-  d->m_type = type->indexed();
+  d->m_type = type ? type->indexed() : IndexedType();
 
   updateCodeModel();
 }
@@ -274,7 +274,7 @@ void Declaration::setAbstractType(AbstractType::Ptr type)
 Declaration* Declaration::specialize(const IndexedInstantiationInformation& /*specialization*/, const TopDUContext* topContext, int /*upDistance*/)
 {
   if(!topContext)
-    return 0;
+    return nullptr;
   return this;
 }
 
@@ -331,7 +331,7 @@ void Declaration::setContext(DUContext* context, bool anonymous)
   if(context)
     m_topContext = context->topContext();
   else
-    m_topContext = 0;
+    m_topContext = nullptr;
 
   d->m_anonymousInContext = anonymous;
   m_context = context;
@@ -460,7 +460,7 @@ void Declaration::setInternalContext(DUContext* context)
 
   //Q_ASSERT( !oldInternalContext || oldInternalContext->owner() == this );
   if( oldInternalContext && oldInternalContext->owner() == this )
-    oldInternalContext->setOwner(0);
+    oldInternalContext->setOwner(nullptr);
 
 
   if( context )
@@ -684,7 +684,13 @@ QMap<IndexedString, QList<RangeInRevision> > Declaration::uses() const
       ranges[range] = true;
   }
 
-  KDevVarLengthArray<IndexedTopDUContext> useContexts = DUChain::uses()->uses(id());
+  DeclarationId _id = id();
+  KDevVarLengthArray<IndexedTopDUContext> useContexts = DUChain::uses()->uses(_id);
+  if (!_id.isDirect())
+  { // also check uses based on direct IDs
+    KDevVarLengthArray<IndexedTopDUContext> directUseContexts = DUChain::uses()->uses(id(true));
+    useContexts.append(directUseContexts.data(), directUseContexts.size());
+  }
 
   foreach (const IndexedTopDUContext indexedContext, useContexts) {
     TopDUContext* context = indexedContext.data();
@@ -731,8 +737,18 @@ bool Declaration::hasUses() const
   ENSURE_CAN_READ
   int idx = topContext()->indexForUsedDeclaration(const_cast<Declaration*>(this), false);
   bool ret = idx != std::numeric_limits<int>::max() && (idx>=0 || hasDeclarationUse(topContext(), idx)); //hasLocalUses
-  ret =  ret || DUChain::uses()->hasUses(id()); //hasUsesInOtherContexts 
-  
+  DeclarationId myId = id();
+
+  if (!ret && DUChain::uses()->hasUses(myId))
+  {
+    ret = true;
+  }
+
+  if (!ret && !myId.isDirect() && DUChain::uses()->hasUses(id(true)))
+  {
+    ret = true;
+  }
+
   return ret;
 }
 
@@ -750,7 +766,13 @@ QMap<IndexedString, QList<KTextEditor::Range> > Declaration::usesCurrentRevision
     }
   }
 
-  KDevVarLengthArray<IndexedTopDUContext> useContexts = DUChain::uses()->uses(id());
+  DeclarationId _id = id();
+  KDevVarLengthArray<IndexedTopDUContext> useContexts = DUChain::uses()->uses(_id);
+  if (!_id.isDirect())
+  { // also check uses based on direct IDs
+    KDevVarLengthArray<IndexedTopDUContext> directUseContexts = DUChain::uses()->uses(id(true));
+    useContexts.append(directUseContexts.data(), directUseContexts.size());
+  }
 
   foreach (const IndexedTopDUContext indexedContext, useContexts) {
     TopDUContext* context = indexedContext.data();
