@@ -1,6 +1,6 @@
 /*
    Copyright 2009 David Nolden <david.nolden.kdevelop@art-master.de>
-   
+
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.
@@ -19,8 +19,10 @@
 #ifndef KDEVPLATFORM_PROBLEMNAVIGATIONCONTEXT_H
 #define KDEVPLATFORM_PROBLEMNAVIGATIONCONTEXT_H
 
+#include <interfaces/iproblem.h>
+#include <interfaces/iassistant.h>
+
 #include <language/duchain/navigation/abstractnavigationcontext.h>
-#include <language/duchain/problem.h>
 #include <language/languageexport.h>
 #include <qpointer.h>
 
@@ -30,15 +32,40 @@ class KDEVPLATFORMLANGUAGE_EXPORT ProblemNavigationContext : public AbstractNavi
 {
   Q_OBJECT
   public:
-    explicit ProblemNavigationContext(KDevelop::ProblemPointer problem);
-    ~ProblemNavigationContext();
-    virtual QString name() const override;  
-    virtual QString html(bool shorten = false) override;    
-    virtual QWidget* widget() const override;
-    virtual bool isWidgetMaximized() const override;
+    enum Flag {
+      NoFlag = 0,
+      ShowLocation = 1 << 0,
+    };
+    Q_DECLARE_FLAGS(Flags, Flag)
+
+    explicit ProblemNavigationContext(const QVector<IProblem::Ptr>& problems, const Flags flags = {});
+    ~ProblemNavigationContext() override;
+
+    QString name() const override;
+    QString html(bool shorten = false) override;
+    QWidget* widget() const override;
+    bool isWidgetMaximized() const override;
+
+    NavigationContextPointer executeKeyAction(QString key) override;
+
+public slots:
+    void executeAction(int index); // TODO: Add API in base class?
+
   private:
+    void html(IProblem::Ptr problem);
+
+    /**
+     * Return HTML-ized text. Used for processing problem's description and explanation.
+     * Some plugins (kdev-cppcheck for example) return already HTML-ized strings,
+     * therefore we should make check for this case.
+     */
+    QString escapedHtml(const QString& text) const;
+
+    QVector<IProblem::Ptr> m_problems;
+    Flags m_flags;
+
     QPointer<QWidget> m_widget;
-    ProblemPointer m_problem;
+    QVector<IAssistantAction::Ptr> m_assistantsActions;
 };
 
 }
