@@ -41,9 +41,9 @@ public:
   /// Destructor
   virtual ~ArrayType();
 
-  virtual AbstractType* clone() const override;
+  AbstractType* clone() const override;
 
-  virtual bool equals(const AbstractType* rhs) const override;
+  bool equals(const AbstractType* rhs) const override;
 
   /**
    * Retrieve the dimension of this array type. Multiple-dimensioned
@@ -75,13 +75,13 @@ public:
    */
   void setElementType(AbstractType::Ptr type);
 
-  virtual QString toString() const override;
+  QString toString() const override;
 
-  virtual uint hash() const override;
+  uint hash() const override;
 
-  virtual WhichType whichType() const override;
+  WhichType whichType() const override;
 
-  virtual void exchangeTypes( TypeExchanger* exchanger ) override;
+  void exchangeTypes( TypeExchanger* exchanger ) override;
 
   enum {
     Identity = 7
@@ -90,7 +90,7 @@ public:
   typedef ArrayTypeData Data;
 
 protected:
-  virtual void accept0 (TypeVisitor *v) const override;
+  void accept0 (TypeVisitor *v) const override;
 
   TYPE_DECLARE_DATA(ArrayType)
 };
@@ -98,7 +98,7 @@ protected:
 template<>
 inline ArrayType* fastCast<ArrayType*>(AbstractType* from) {
   if(!from || from->whichType() != AbstractType::TypeArray)
-    return 0;
+    return nullptr;
   else
     return static_cast<ArrayType*>(from);
 }
