@@ -30,11 +30,11 @@ class EditorContextPrivate
 {
 public:
     EditorContextPrivate( KTextEditor::View* view, const KTextEditor::Cursor& position )
-        : m_view( view )
+        : m_url(view->document()->url())
+        , m_position(position)
+        , m_currentLine(view->document()->line(m_position.line()))
+        , m_view( view )
     {
-        m_url = view->document()->url();
-        m_position = position;
-        m_currentLine = view->document()->line(m_position.line());
         int wordStart = m_position.column();
         int wordEnd = m_position.column();
         while(wordStart > 0 && wordStart < m_currentLine.length() && (m_currentLine[wordStart-1].isLetterOrNumber() || m_currentLine[wordStart-1] == '_'))
@@ -68,6 +68,11 @@ QUrl EditorContext::url() const
     return d->m_url;
 }
 
+QList<QUrl> EditorContext::urls() const
+{
+    return {d->m_url};
+}
+
 KTextEditor::Cursor EditorContext::position() const
 {
     return d->m_position;
