@@ -20,12 +20,11 @@
 #include <limits>
 #include <serialization/itemrepository.h>
 #include <QtCore/QMutex>
-#include <QtCore/QStack>
 #include <algorithm>
 
-//#define DEBUG
+//#define DEBUG_SETREPOSITORY
 
-#ifdef DEBUG
+#ifdef DEBUG_SETREPOSITORY
 #define ifDebug(X) X
 #else
 #define ifDebug(x)
@@ -33,7 +32,7 @@
 #define Q_ASSERT(x)
 #endif
 
-#ifndef DEBUG
+#ifndef DEBUG_SETREPOSITORY
 #define CHECK_SPLIT_POSITION(Node)
 #else
 #define CHECK_SPLIT_POSITION(node) Q_ASSERT(!(node).leftNode || (getLeftNode(&node)->end() <= splitPositionForRange((node).start, (node).end) && getRightNode(&node)->start() >= splitPositionForRange((node).start, (node).end)))
@@ -104,7 +103,7 @@ struct SetRepositoryAlgorithms {
   QString shortLabel(const SetNodeData& node) const;
 
   uint set_union(uint firstNode, uint secondNode, const SetNodeData* first, const SetNodeData* second, uchar splitBit = 31);
-  uint createSetFromNodes(uint leftNode, uint rightNode, const SetNodeData* left = 0, const SetNodeData* right = 0);
+  uint createSetFromNodes(uint leftNode, uint rightNode, const SetNodeData* left = nullptr, const SetNodeData* right = nullptr);
   uint computeSetFromNodes(uint leftNode, uint rightNode, const SetNodeData* left, const SetNodeData* right, uchar splitBit);
   uint set_intersect(uint firstNode, uint secondNode, const SetNodeData* first, const SetNodeData* second, uchar splitBit = 31);
   bool set_contains(const SetNodeData* node, Index index);
@@ -192,7 +191,7 @@ void SetNodeDataRequest::createItem(SetNodeData* item) const {
 
     Q_ASSERT((item->rightNode() && item->leftNode()) || (!item->rightNode() && !item->leftNode()));
 
-    #ifdef DEBUG
+#ifdef DEBUG_SETREPOSITORY
     //Make sure we split at the correct split position
     if(item->hasSlaves()) {
         uint split = splitPositionForRange(data.start, data.end);
@@ -200,7 +199,7 @@ void SetNodeDataRequest::createItem(SetNodeData* item) const {
         const SetNodeData* right = repository.itemFromIndex(item->rightNode());
         Q_ASSERT(split >= left->end() && split <= right->start());
     }
-    #endif
+#endif
     if(!data.leftNode() && setRepository) {
         for(uint a = item->start(); a < item->end(); ++a)
             setRepository->itemAddedToSets(a);
@@ -226,7 +225,7 @@ public:
   private:
 };
 
-Set::Set() : m_tree(0), m_repository(0) {
+Set::Set() : m_tree(0), m_repository(nullptr) {
 }
 
 Set::~Set() {
@@ -342,7 +341,7 @@ const int nodeStackAlloc = 500;
 class Set::Iterator::IteratorPrivate {
 public:
 
-  IteratorPrivate() : nodeStackSize(0), currentIndex(0), repository(0) {
+  IteratorPrivate() : nodeStackSize(0), currentIndex(0), repository(nullptr) {
     nodeStackData.resize(nodeStackAlloc);
     nodeStack = nodeStackData.data();
   }
@@ -532,7 +531,7 @@ uint SetRepositoryAlgorithms::computeSetFromNodes(uint leftNode, uint rightNode,
     //Create a new set from left + rightLeft, and from rightRight. That set will have the correct split-position.
     uint newLeftNode = computeSetFromNodes(leftNode, rightLeftNode, left, rightLeft, splitBit);
 
-    return createSetFromNodes(newLeftNode, rightRightNode, 0, rightRight);
+    return createSetFromNodes(newLeftNode, rightRightNode, nullptr, rightRight);
   }else{
     return createSetFromNodes(leftNode, rightNode, left, right);
   }
@@ -596,7 +595,7 @@ uint SetRepositoryAlgorithms::set_union(uint firstNode, uint secondNode, const S
     //So we only need to union that side of first with second.
 
     if(secondEnd <= splitPosition) {
-      return createSetFromNodes( set_union(firstLeftNode, secondNode, firstLeft, second, splitBit), firstRightNode, 0, firstRight );
+      return createSetFromNodes( set_union(firstLeftNode, secondNode, firstLeft, second, splitBit), firstRightNode, nullptr, firstRight );
     }else{
       Q_ASSERT(secondStart >= splitPosition);
       return createSetFromNodes( firstLeftNode, set_union(firstRightNode, secondNode, firstRight, second, splitBit), firstLeft );
@@ -613,7 +612,7 @@ uint SetRepositoryAlgorithms::set_union(uint firstNode, uint secondNode, const S
     Q_ASSERT(splitPosition >= secondLeft->end() && splitPosition <= secondRight->start());
 
     if(firstEnd <= splitPosition) {
-      return createSetFromNodes( set_union(secondLeftNode, firstNode, secondLeft, first, splitBit), secondRightNode, 0, secondRight );
+      return createSetFromNodes( set_union(secondLeftNode, firstNode, secondLeft, first, splitBit), secondRightNode, nullptr, secondRight );
     }else{
       Q_ASSERT(firstStart >= splitPosition);
       return createSetFromNodes( secondLeftNode, set_union(secondRightNode, firstNode, secondRight, first, splitBit), secondLeft );
@@ -888,7 +887,7 @@ Set BasicSetRepository::createSet(const std::set<Index>& indices) {
   return createSetFromIndices(indicesVector);
 }
 
-BasicSetRepository::BasicSetRepository(QString name, KDevelop::ItemRepositoryRegistry* registry, bool delayedDeletion) : d(new Private(name)), dataRepository(this, name, registry), m_mutex(0), m_delayedDeletion(delayedDeletion) {
+BasicSetRepository::BasicSetRepository(QString name, KDevelop::ItemRepositoryRegistry* registry, bool delayedDeletion) : d(new Private(name)), dataRepository(this, name, registry), m_mutex(nullptr), m_delayedDeletion(delayedDeletion) {
     m_mutex = dataRepository.mutex();
 }
 
@@ -1054,9 +1053,9 @@ void Set::staticRef() {
   if(!m_tree)
     return;
 
-    QMutexLocker lock(m_repository->m_mutex);
-    SetNodeData* data = m_repository->dataRepository.dynamicItemFromIndexSimple(m_tree);
-    ++data->m_refCount;
+  QMutexLocker lock(m_repository->m_mutex);
+  SetNodeData* data = m_repository->dataRepository.dynamicItemFromIndexSimple(m_tree);
+  ++data->m_refCount;
 }
 
 ///Mutex must be locked
@@ -1089,9 +1088,9 @@ void Set::staticUnref() {
   if(!m_tree)
     return;
 
-    QMutexLocker lock(m_repository->m_mutex);
+  QMutexLocker lock(m_repository->m_mutex);
 
-    unrefNode(m_tree);
+  unrefNode(m_tree);
 }
 
 StringSetRepository::StringSetRepository(QString name) : Utils::BasicSetRepository(name) {
