@@ -74,6 +74,9 @@
 
 #include <language/util/navigationtooltip.h>
 
+#include <shell/problemmodel.h>
+#include <shell/problemmodelset.h>
+
 #include <util/texteditorhelpers.h>
 
 #include <sublime/mainwindow.h>
@@ -113,7 +116,7 @@ DUContext* contextForHighlightingAt(const KTextEditor::Cursor& position, TopDUCo
 DUContext* getContextAt(const QUrl& url, KTextEditor::Cursor cursor)
 {
   TopDUContext* topContext = DUChainUtils::standardContextForUrl(url);
-  if (!topContext) return 0;
+  if (!topContext) return nullptr;
   return contextForHighlightingAt(KTextEditor::Cursor(cursor), topContext);
 }
 
@@ -137,7 +140,7 @@ class ContextBrowserViewFactory: public KDevelop::IToolViewFactory
 public:
     ContextBrowserViewFactory(ContextBrowserPlugin *plugin): m_plugin(plugin) {}
 
-    QWidget* create(QWidget *parent = 0) override
+    QWidget* create(QWidget *parent = nullptr) override
     {
         ContextBrowserView* ret = new ContextBrowserView(m_plugin, parent);
         return ret;
@@ -167,7 +170,6 @@ KXMLGUIClient* ContextBrowserPlugin::createGUIForMainWindow( Sublime::MainWindow
 
     m_previousButton = new QToolButton();
     m_previousButton->setToolTip(i18n("Go back in context history"));
-    m_previousButton->setAutoRaise(true);
     m_previousButton->setPopupMode(QToolButton::MenuButtonPopup);
     m_previousButton->setIcon(QIcon::fromTheme(QStringLiteral("go-previous")));
     m_previousButton->setEnabled(false);
@@ -179,7 +181,6 @@ KXMLGUIClient* ContextBrowserPlugin::createGUIForMainWindow( Sublime::MainWindow
 
     m_nextButton = new QToolButton();
     m_nextButton->setToolTip(i18n("Go forward in context history"));
-    m_nextButton->setAutoRaise(true);
     m_nextButton->setPopupMode(QToolButton::MenuButtonPopup);
     m_nextButton->setIcon(QIcon::fromTheme(QStringLiteral("go-next")));
     m_nextButton->setEnabled(false);
@@ -293,8 +294,6 @@ ContextBrowserPlugin::ContextBrowserPlugin(QObject *parent, const QVariantList&)
     , m_nextHistoryIndex(0)
     , m_textHintProvider(this)
 {
-  KDEV_USE_EXTENSION_INTERFACE( IContextBrowser )
-
   core()->uiController()->addToolView(i18n("Code Browser"), m_viewFactory);
 
   connect( core()->documentController(), &IDocumentController::textDocumentCreated, this, &ContextBrowserPlugin::textDocumentCreated );
@@ -437,36 +436,45 @@ void ContextBrowserPlugin::startDelayedBrowsing(KTextEditor::View* view) {
 void ContextBrowserPlugin::hideToolTip() {
   if(m_currentToolTip) {
     m_currentToolTip->deleteLater();
-    m_currentToolTip = 0;
-    m_currentNavigationWidget = 0;
-    m_currentToolTipProblem = {};
+    m_currentToolTip = nullptr;
+    m_currentNavigationWidget = nullptr;
+    m_currentToolTipProblems.clear();
     m_currentToolTipDeclaration = {};
   }
 }
 
-static ProblemPointer findProblemUnderCursor(TopDUContext* topContext, KTextEditor::Cursor position)
+static QVector<KDevelop::IProblem::Ptr> findProblemsUnderCursor(TopDUContext* topContext, KTextEditor::Cursor position)
 {
-  const auto top = ReferencedTopDUContext(topContext);
-  foreach (auto problem, DUChainUtils::allProblemsForContext(top)) {
-    if (problem->rangeInCurrentRevision().contains(position)) {
-      return problem;
+  QVector<KDevelop::IProblem::Ptr> problems;
+  auto modelsData = ICore::self()->languageController()->problemModelSet()->models();
+  foreach (auto modelData, modelsData) {
+    foreach (auto problem, modelData.model->problems(topContext->url())) {
+      DocumentRange problemRange = problem->finalLocation();
+      if (problemRange.contains(position) || (problemRange.isEmpty() && problemRange.boundaryAtCursor(position)))
+        problems += problem;
     }
   }
 
-  return {};
+  return problems;
 }
 
-static ProblemPointer findProblemCloseToCursor(TopDUContext* topContext, KTextEditor::Cursor position, KTextEditor::View* view)
+static QVector<KDevelop::IProblem::Ptr> findProblemsCloseToCursor(TopDUContext* topContext, KTextEditor::Cursor position, KTextEditor::View* view)
 {
-  const auto top = ReferencedTopDUContext(topContext);
-  auto problems = DUChainUtils::allProblemsForContext(top);
-  if (problems.isEmpty())
-    return {};
+  QVector<KDevelop::IProblem::Ptr> allProblems;
+  auto modelsData = ICore::self()->languageController()->problemModelSet()->models();
+  foreach (auto modelData, modelsData) {
+    foreach (auto problem, modelData.model->problems(topContext->url())) {
+      allProblems += problem;
+    }
+  }
 
-  auto closestProblem = std::min_element(problems.constBegin(), problems.constEnd(),
-                                         [position](const ProblemPointer& a, const ProblemPointer& b) {
-    const auto aRange = a->rangeInCurrentRevision();
-    const auto bRange = b->rangeInCurrentRevision();
+  if (allProblems.isEmpty())
+    return allProblems;
+
+  std::sort(allProblems.begin(), allProblems.end(),
+            [position](const KDevelop::IProblem::Ptr a, const KDevelop::IProblem::Ptr b) {
+    const auto aRange = a->finalLocation();
+    const auto bRange = b->finalLocation();
 
     const auto aLineDistance = qMin(qAbs(aRange.start().line() - position.line()),
                                     qAbs(aRange.end().line() - position.line()));
@@ -484,32 +492,40 @@ static ProblemPointer findProblemCloseToCursor(TopDUContext* topContext, KTextEd
       qAbs(bRange.end().column() - position.column());
   });
 
-  auto r = (*closestProblem)->rangeInCurrentRevision();
-  if (!r.contains(position)) {
-    if (r.start().line() == position.line() || r.end().line() == position.line()) {
-      // problem is on the same line, let's use it
-      return *closestProblem;
-    }
+  QVector<KDevelop::IProblem::Ptr> closestProblems;
 
-    // if not, only show it in case there's only whitespace
-    // between the current cursor position and the problem line
-    KTextEditor::Range dist;
-    KTextEditor::Cursor bound(r.start().line(), 0);
-    if (position < r.start())
-      dist = KTextEditor::Range(position, bound);
-    else {
-      bound.setLine(r.end().line() + 1);
-      dist = KTextEditor::Range(bound, position);
-    }
+  // Show problems, located on the same line
+  foreach (auto problem, allProblems) {
+    auto r = problem->finalLocation();
+    if (r.onSingleLine() && r.start().line() == position.line())
+      closestProblems += problem;
+    else
+      break;
+  }
 
-    auto textBetween = view->document()->text(dist);
-    auto isSpace = std::all_of(textBetween.begin(), textBetween.end(), [](QChar c) { return c.isSpace(); });
-    if (!isSpace) {
-      return {};
+  // If not, only show it in case there's only whitespace
+  // between the current cursor position and the problem line
+  if (closestProblems.isEmpty()) {
+    foreach (auto problem, allProblems) {
+      auto r = problem->finalLocation();
+
+      KTextEditor::Range dist;
+      KTextEditor::Cursor bound(r.start().line(), 0);
+      if (position < r.start())
+        dist = KTextEditor::Range(position, bound);
+      else {
+        bound.setLine(r.end().line() + 1);
+        dist = KTextEditor::Range(bound, position);
+      }
+
+      if (view->document()->text(dist).trimmed().isEmpty())
+        closestProblems += problem;
+      else
+        break;
     }
   }
 
-  return *closestProblem;
+  return closestProblems;
 }
 
 QWidget* ContextBrowserPlugin::navigationWidgetForPosition(KTextEditor::View* view, KTextEditor::Cursor position)
@@ -528,15 +544,15 @@ QWidget* ContextBrowserPlugin::navigationWidgetForPosition(KTextEditor::View* vi
   TopDUContext* topContext = DUChainUtils::standardContextForUrl(view->document()->url());
   if (topContext) {
     // first pass: find problems under the cursor
-    const auto problem = findProblemUnderCursor(topContext, position);
-    if (problem) {
-      if (problem == m_currentToolTipProblem && m_currentToolTip) {
+    const auto problems = findProblemsUnderCursor(topContext, position);
+    if (!problems.isEmpty()) {
+      if (problems == m_currentToolTipProblems && m_currentToolTip) {
         return nullptr;
       }
 
-      m_currentToolTipProblem = problem;
+      m_currentToolTipProblems = problems;
       auto widget = new AbstractNavigationWidget;
-      auto context = new ProblemNavigationContext(problem);
+      auto context = new ProblemNavigationContext(problems);
       context->setTopContext(TopDUContextPointer(topContext));
       widget->setContext(NavigationContextPointer(context));
       return widget;
@@ -561,16 +577,16 @@ QWidget* ContextBrowserPlugin::navigationWidgetForPosition(KTextEditor::View* vi
 
   if (topContext) {
     // second pass: find closest problem to the cursor
-    const auto problem = findProblemCloseToCursor(topContext, position, view);
-    if (problem) {
-      if (problem == m_currentToolTipProblem && m_currentToolTip) {
+    const auto problems = findProblemsCloseToCursor(topContext, position, view);
+    if (!problems.isEmpty()) {
+      if (problems == m_currentToolTipProblems && m_currentToolTip) {
         return nullptr;
       }
 
-      m_currentToolTipProblem = problem;
+      m_currentToolTipProblems = problems;
       auto widget = new AbstractNavigationWidget;
       // since the problem is not under cursor: show location
-      widget->setContext(NavigationContextPointer(new ProblemNavigationContext(problem, ProblemNavigationContext::ShowLocation)));
+      widget->setContext(NavigationContextPointer(new ProblemNavigationContext(problems, ProblemNavigationContext::ShowLocation)));
       return widget;
     }
   }
@@ -579,7 +595,6 @@ QWidget* ContextBrowserPlugin::navigationWidgetForPosition(KTextEditor::View* vi
 }
 
 void ContextBrowserPlugin::showToolTip(KTextEditor::View* view, KTextEditor::Cursor position) {
-
   ContextBrowserView* contextView = browserViewForWidget(view);
   if(contextView && contextView->isVisible() && !contextView->isLocked())
     return; // If the context-browser view is visible, it will care about updating by itself
@@ -594,8 +609,8 @@ void ContextBrowserPlugin::showToolTip(KTextEditor::View* view, KTextEditor::Cur
 
     if(m_currentToolTip) {
       m_currentToolTip->deleteLater();
-      m_currentToolTip = 0;
-      m_currentNavigationWidget = 0;
+      m_currentToolTip = nullptr;
+      m_currentNavigationWidget = nullptr;
     }
 
     KDevelop::NavigationToolTip* tooltip = new KDevelop::NavigationToolTip(view, view->mapToGlobal(view->cursorToCoordinate(position)) + QPoint(20, 40), navigationWidget);
@@ -695,7 +710,7 @@ void ContextBrowserPlugin::addHighlight( View* view, KDevelop::Declaration* decl
 Declaration* ContextBrowserPlugin::findDeclaration(View* view, const KTextEditor::Cursor& position, bool mouseHighlight)
 {
       Q_UNUSED(mouseHighlight);
-      Declaration* foundDeclaration = 0;
+      Declaration* foundDeclaration = nullptr;
       if(m_useDeclaration.data()) {
         foundDeclaration = m_useDeclaration.data();
       }else{
@@ -719,7 +734,7 @@ ContextBrowserView* ContextBrowserPlugin::browserViewForWidget(QWidget* widget)
     }
   }
 
-  return 0;
+  return nullptr;
 }
 
 void ContextBrowserPlugin::updateForView(View* view)
@@ -770,7 +785,7 @@ void ContextBrowserPlugin::updateForView(View* view)
     ///Check whether there is a special language object to highlight (for example a macro)
 
     KTextEditor::Range specialRange = language->specialLanguageObjectRange(url, highlightPosition);
-    ContextBrowserView* updateBrowserView = shouldUpdateBrowser ?  browserViewForWidget(view) : 0;
+    ContextBrowserView* updateBrowserView = shouldUpdateBrowser ?  browserViewForWidget(view) : nullptr;
 
     if(specialRange.isValid())
     {
@@ -897,7 +912,7 @@ void ContextBrowserPlugin::cursorPositionChanged( View* view, const KTextEditor:
   if(view->document() == m_lastInsertionDocument && newPosition == m_lastInsertionPos)
   {
     //Do not update the highlighting while typing
-    m_lastInsertionDocument = 0;
+    m_lastInsertionDocument = nullptr;
     m_lastInsertionPos = KTextEditor::Cursor();
     if(m_highlightedRanges.contains(view))
       m_highlightedRanges[view].keep = true;
@@ -965,7 +980,7 @@ void ContextBrowserPlugin::switchUse(bool forward)
       KTextEditor::Cursor cCurrent(view->cursorPosition());
       KDevelop::CursorInRevision c = chosen->transformToLocalRevision(cCurrent);
 
-      Declaration* decl = 0;
+      Declaration* decl = nullptr;
       //If we have a locked declaration, use that for jumping
       foreach(ContextBrowserView* view, m_views) {
         decl = view->lockedDeclaration().data(); ///@todo Somehow match the correct context-browser view if there is multiple
@@ -985,7 +1000,7 @@ void ContextBrowserPlugin::switchUse(bool forward)
 
       if(decl) {
 
-        Declaration* target = 0;
+        Declaration* target = nullptr;
         if(forward)
           //Try jumping from definition to declaration
           target = DUChainUtils::declarationForDefinition(decl, chosen);
