@@ -57,7 +57,7 @@ class KDevCvsViewFactory: public KDevelop::IToolViewFactory
 {
 public:
     KDevCvsViewFactory(CvsPlugin *plugin): m_plugin(plugin) {}
-    QWidget* create(QWidget *parent = 0) override {
+    QWidget* create(QWidget *parent = nullptr) override {
         return new CvsMainView(m_plugin, parent);
     }
     Qt::DockWidgetArea defaultPosition() override {
@@ -88,9 +88,6 @@ CvsPlugin::CvsPlugin(QObject *parent, const QVariantList &)
         : KDevelop::IPlugin(QStringLiteral("kdevcvs"), parent)
         , d(new CvsPluginPrivate(this))
 {
-    KDEV_USE_EXTENSION_INTERFACE(KDevelop::IBasicVersionControl)
-    KDEV_USE_EXTENSION_INTERFACE(KDevelop::ICentralizedVersionControl)
-
     core()->uiController()->addToolView(i18n("CVS"), d->m_factory);
 
     setXMLFile(QStringLiteral("kdevcvs.rc"));
@@ -282,7 +279,7 @@ bool CvsPlugin::isVersionControlled(const QUrl & localLocation)
 KDevelop::VcsJob * CvsPlugin::repositoryLocation(const QUrl & localLocation)
 {
     Q_UNUSED(localLocation);
-    return NULL;
+    return nullptr;
 }
 
 KDevelop::VcsJob * CvsPlugin::add(const QList<QUrl> & localLocations, KDevelop::IBasicVersionControl::RecursionMode recursion)
@@ -303,7 +300,7 @@ KDevelop::VcsJob * CvsPlugin::remove(const QList<QUrl> & localLocations)
 KDevelop::VcsJob * CvsPlugin::localRevision(const QUrl & localLocation, KDevelop::VcsRevision::RevisionType)
 {
     Q_UNUSED(localLocation)
-    return NULL;
+    return nullptr;
 }
 
 KDevelop::VcsJob * CvsPlugin::status(const QList<QUrl> & localLocations, KDevelop::IBasicVersionControl::RecursionMode recursion)
@@ -332,7 +329,7 @@ KDevelop::VcsJob * CvsPlugin::copy(const QUrl & localLocationSrc, const QUrl & l
 {
     bool ok = QFile::copy(localLocationSrc.toLocalFile(), localLocationDstn.path());
     if (!ok) {
-        return NULL;
+        return nullptr;
     }
 
     QList<QUrl> listDstn;
@@ -346,7 +343,7 @@ KDevelop::VcsJob * CvsPlugin::copy(const QUrl & localLocationSrc, const QUrl & l
 
 KDevelop::VcsJob * CvsPlugin::move(const QUrl &, const QUrl &)
 {
-    return NULL;
+    return nullptr;
 }
 
 KDevelop::VcsJob * CvsPlugin::revert(const QList<QUrl> & localLocations, KDevelop::IBasicVersionControl::RecursionMode recursion)
@@ -419,7 +416,7 @@ KDevelop::VcsJob * CvsPlugin::resolve(const QList<QUrl> & localLocations, KDevel
 {
     Q_UNUSED(localLocations);
     Q_UNUSED(recursion);
-    return NULL;
+    return nullptr;
 }
 
 KDevelop::VcsJob * CvsPlugin::import(const QString& commitMessage, const QUrl& sourceDirectory, const KDevelop::VcsLocation& destinationRepository)
@@ -428,7 +425,7 @@ KDevelop::VcsJob * CvsPlugin::import(const QString& commitMessage, const QUrl& s
             || !sourceDirectory.isLocalFile()
             || !destinationRepository.isValid()
             || destinationRepository.type() != KDevelop::VcsLocation::RepositoryLocation) {
-        return 0;
+        return nullptr;
     }
 
     qCDebug(PLUGIN_CVS) << "CVS Import requested "
@@ -451,7 +448,7 @@ KDevelop::VcsJob * CvsPlugin::createWorkingCopy(const KDevelop::VcsLocation & so
     if (!destinationDirectory.isLocalFile()
             || !sourceRepository.isValid()
             || sourceRepository.type() != KDevelop::VcsLocation::RepositoryLocation) {
-        return 0;
+        return nullptr;
     }
 
     qCDebug(PLUGIN_CVS) << "CVS Checkout requested "
