@@ -185,8 +185,8 @@ CvsJob* CvsProxy::log(const QUrl &url, const KDevelop::VcsRevision& rev)
 
         return job;
     }
-    if (job) delete job;
-    return NULL;
+    delete job;
+    return nullptr;
 }
 
 CvsJob* CvsProxy::diff(const QUrl& url,
@@ -229,8 +229,8 @@ CvsJob* CvsProxy::diff(const QUrl& url,
 
         return job;
     }
-    if (job) delete job;
-    return NULL;
+    delete job;
+    return nullptr;
 }
 
 CvsJob * CvsProxy::annotate(const QUrl& url, const KDevelop::VcsRevision& rev)
@@ -250,8 +250,8 @@ CvsJob * CvsProxy::annotate(const QUrl& url, const KDevelop::VcsRevision& rev)
 
         return job;
     }
-    if (job) delete job;
-    return NULL;
+    delete job;
+    return nullptr;
 }
 
 CvsJob* CvsProxy::edit(const QString& repo, const QList<QUrl>& files)
@@ -265,8 +265,8 @@ CvsJob* CvsProxy::edit(const QString& repo, const QList<QUrl>& files)
 
         return job;
     }
-    if (job) delete job;
-    return NULL;
+    delete job;
+    return nullptr;
 }
 
 
@@ -281,8 +281,8 @@ CvsJob* CvsProxy::unedit(const QString& repo, const QList<QUrl>& files)
 
         return job;
     }
-    if (job) delete job;
-    return NULL;
+    delete job;
+    return nullptr;
 }
 
 CvsJob* CvsProxy::editors(const QString& repo, const QList<QUrl>& files)
@@ -296,8 +296,8 @@ CvsJob* CvsProxy::editors(const QString& repo, const QList<QUrl>& files)
 
         return job;
     }
-    if (job) delete job;
-    return NULL;
+    delete job;
+    return nullptr;
 }
 
 CvsJob* CvsProxy::commit(const QString& repo, const QList<QUrl>& files, const QString& message)
@@ -314,8 +314,8 @@ CvsJob* CvsProxy::commit(const QString& repo, const QList<QUrl>& files, const QS
 
         return job;
     }
-    if (job) delete job;
-    return NULL;
+    delete job;
+    return nullptr;
 }
 
 CvsJob* CvsProxy::add(const QString& repo, const QList<QUrl>& files,
@@ -336,8 +336,8 @@ CvsJob* CvsProxy::add(const QString& repo, const QList<QUrl>& files,
 
         return job;
     }
-    if (job) delete job;
-    return NULL;
+    delete job;
+    return nullptr;
 }
 
 CvsJob * CvsProxy::remove(const QString& repo, const QList<QUrl>& files)
@@ -353,8 +353,8 @@ CvsJob * CvsProxy::remove(const QString& repo, const QList<QUrl>& files)
 
         return job;
     }
-    if (job) delete job;
-    return NULL;
+    delete job;
+    return nullptr;
 }
 
 CvsJob * CvsProxy::update(const QString& repo, const QList<QUrl>& files,
@@ -386,8 +386,8 @@ CvsJob * CvsProxy::update(const QString& repo, const QList<QUrl>& files,
 
         return job;
     }
-    if (job) delete job;
-    return NULL;
+    delete job;
+    return nullptr;
 }
 
 CvsJob * CvsProxy::import(const QUrl& directory,
@@ -412,8 +412,8 @@ CvsJob * CvsProxy::import(const QUrl& directory,
 
         return job;
     }
-    if (job) delete job;
-    return NULL;
+    delete job;
+    return nullptr;
 }
 
 CvsJob * CvsProxy::checkout(const QUrl& targetDir,
@@ -451,8 +451,8 @@ CvsJob * CvsProxy::checkout(const QUrl& targetDir,
 
         return job;
     }
-    if (job) delete job;
-    return NULL;
+    delete job;
+    return nullptr;
 }
 
 CvsJob * CvsProxy::status(const QString & repo, const QList<QUrl> & files, bool recursive, bool taginfo)
@@ -474,7 +474,7 @@ CvsJob * CvsProxy::status(const QString & repo, const QList<QUrl> & files, bool
 
         return job;
     }
-    if (job) delete job;
-    return NULL;
+    delete job;
+    return nullptr;
 }
 
