@@ -58,17 +58,17 @@
 #include <KIO/Global>
 #include <KLocalizedString>
 
-#define REMOVE_PAGE(name)       \
-if (d->name##Page)              \
-{                               \
-    removePage(d->name##Page);  \
-    d->name##Page = 0;          \
-    d->name##PageWidget = 0;    \
+#define REMOVE_PAGE(name)          \
+if (d->name##Page)                 \
+{                                  \
+    removePage(d->name##Page);     \
+    d->name##Page = nullptr;       \
+    d->name##PageWidget = nullptr; \
 }
 
-#define ZERO_PAGE(name)         \
-d->name##Page = 0;              \
-d->name##PageWidget = 0;
+#define ZERO_PAGE(name)  \
+d->name##Page = nullptr; \
+d->name##PageWidget = nullptr;
 
 using namespace KDevelop;
 
@@ -111,9 +111,9 @@ public:
 
 TemplateClassAssistantPrivate::TemplateClassAssistantPrivate(const QUrl& baseUrl)
 : baseUrl(baseUrl)
-, helper(0)
-, generator(0)
-, renderer(0)
+, helper(nullptr)
+, generator(nullptr)
+, renderer(nullptr)
 {
 }
 
@@ -162,7 +162,7 @@ void TemplateClassAssistantPrivate::addFilesToTarget (const QHash< QString, QUrl
     }
 
     QList<ProjectTargetItem*> targets;
-    ProjectTargetItem* target = 0;
+    ProjectTargetItem* target = nullptr;
 
     foreach (ProjectBaseItem* item, items)
     {
@@ -307,13 +307,7 @@ void TemplateClassAssistant::setup()
     d->templateSelectionPage->setIcon(QIcon::fromTheme(QStringLiteral("project-development-new-template")));
 
     d->dummyPage = addPage(new QWidget(this), QStringLiteral("Dummy Page"));
-
-    // KAssistantDialog creates a help button by default, no option to prevent that
-    QPushButton *helpButton = button(QDialogButtonBox::Help);
-    if (helpButton) {
-        buttonBox()->removeButton(helpButton);
-        delete helpButton;
-    }
+//     showButton(QDialog::Help, false);
 }
 
 void TemplateClassAssistant::templateChosen(const QString& templateDescription)
@@ -321,7 +315,7 @@ void TemplateClassAssistant::templateChosen(const QString& templateDescription)
     d->fileTemplate.setTemplateDescription(templateDescription);
     d->type = d->fileTemplate.type();
 
-    d->generator = 0;
+    d->generator = nullptr;
 
     if (!d->fileTemplate.isValid())
     {
@@ -360,7 +354,7 @@ void TemplateClassAssistant::templateChosen(const QString& templateDescription)
         d->membersPage->setIcon(QIcon::fromTheme(QStringLiteral("field")));
         setValid(d->membersPage, true);
 
-        d->helper = 0;
+        d->helper = nullptr;
         QString languageName = d->fileTemplate.languageName();
         auto language = ICore::self()->languageController()->language(languageName);
         if (language)
@@ -521,7 +515,7 @@ void TemplateClassAssistant::back()
         REMOVE_PAGE(license)
 
         delete d->helper;
-        d->helper = 0;
+        d->helper = nullptr;
 
         if (d->generator)
         {
@@ -531,8 +525,8 @@ void TemplateClassAssistant::back()
         {
             delete d->renderer;
         }
-        d->generator = 0;
-        d->renderer = 0;
+        d->generator = nullptr;
+        d->renderer = nullptr;
 
         if (d->baseUrl.isValid())
         {
