@@ -181,16 +181,10 @@ GitPlugin::GitPlugin( QObject *parent, const QVariantList & )
     : DistributedVersionControlPlugin(parent, QStringLiteral("kdevgit")), m_oldVersion(false), m_usePrefix(true)
 {
     if (QStandardPaths::findExecutable(QStringLiteral("git")).isEmpty()) {
-        m_hasError = true;
-        m_errorDescription = i18n("git is not installed");
+        setErrorDescription(i18n("Unable to find git executable. Is it installed on the system?"));
         return;
     }
 
-    KDEV_USE_EXTENSION_INTERFACE( KDevelop::IBasicVersionControl )
-    KDEV_USE_EXTENSION_INTERFACE( KDevelop::IDistributedVersionControl )
-    KDEV_USE_EXTENSION_INTERFACE( KDevelop::IBranchingVersionControl )
-
-    m_hasError = false;
     setObjectName(QStringLiteral("Git"));
 
     DVcsJob* versionJob = new DVcsJob(QDir::tempPath(), this, KDevelop::OutputJob::Silent);
@@ -256,7 +250,7 @@ void GitPlugin::ctxPopStash()
 
 void GitPlugin::ctxStashManager()
 {
-    QPointer<StashManagerDialog> d = new StashManagerDialog(urlDir(m_urls), this, 0);
+    QPointer<StashManagerDialog> d = new StashManagerDialog(urlDir(m_urls), this, nullptr);
     d->exec();
 
     delete d;
@@ -283,7 +277,7 @@ bool GitPlugin::isValidDirectory(const QUrl & dirPath)
 {
     QDir dir=dotGitDirectory(dirPath);
 
-    return dir.cd(QStringLiteral(".git")) && dir.exists(QStringLiteral("HEAD"));
+    return dir.exists(QStringLiteral(".git/HEAD"));
 }
 
 bool GitPlugin::isVersionControlled(const QUrl &path)
@@ -363,12 +357,15 @@ VcsJob* GitPlugin::diff(const QUrl& fileOrDirectory, const KDevelop::VcsRevision
         // has become optional.
         *job << "--no-prefix";
     }
-    if(srcRevision.revisionType()==VcsRevision::Special
-        && dstRevision.revisionType()==VcsRevision::Special
-        && srcRevision.specialType()==VcsRevision::Base
-        && dstRevision.specialType()==VcsRevision::Working)
-        *job << "HEAD";
-    else {
+    if (dstRevision.revisionType() == VcsRevision::Special &&
+         dstRevision.specialType() == VcsRevision::Working) {
+        if (srcRevision.revisionType() == VcsRevision::Special &&
+             srcRevision.specialType() == VcsRevision::Base) {
+            *job << "HEAD";
+        } else {
+            *job << "--cached" << srcRevision.revisionValue().toString();
+        }
+    } else {
         QString revstr = revisionInterval(srcRevision, dstRevision);
         if(!revstr.isEmpty())
             *job << revstr;
@@ -538,7 +535,7 @@ VcsJob* GitPlugin::remove(const QList<QUrl>& files)
         }
     }
 
-    if (files_.isEmpty()) return 0;
+    if (files_.isEmpty()) return nullptr;
 
     DVcsJob* job = new GitJob(dotGitDir, this);
     job->setType(VcsJob::Remove);
@@ -593,7 +590,7 @@ KDevelop::VcsJob* GitPlugin::annotate(const QUrl &localLocation, const KDevelop:
 void GitPlugin::parseGitBlameOutput(DVcsJob *job)
 {
     QVariantList results;
-    VcsAnnotationLine* annotation = 0;
+    VcsAnnotationLine* annotation = nullptr;
     const auto output = job->output();
     const auto lines = output.splitRef('\n');
 
@@ -678,7 +675,7 @@ VcsJob* GitPlugin::switchBranch(const QUrl &repository, const QString &branch)
 {
     QDir d=urlDir(repository);
 
-    if(hasModifications(d) && KMessageBox::questionYesNo(0, i18n("There are pending changes, do you want to stash them first?"))==KMessageBox::Yes) {
+    if(hasModifications(d) && KMessageBox::questionYesNo(nullptr, i18n("There are pending changes, do you want to stash them first?"))==KMessageBox::Yes) {
         QScopedPointer<DVcsJob> stash(gitStash(d, QStringList(), KDevelop::OutputJob::Verbose));
         stash->exec();
     }
@@ -1444,7 +1441,7 @@ class GitVcsLocationWidget : public KDevelop::StandardVcsLocationWidget
 {
     Q_OBJECT
     public:
-        GitVcsLocationWidget(QWidget* parent = 0, Qt::WindowFlags f = 0)
+        GitVcsLocationWidget(QWidget* parent = nullptr, Qt::WindowFlags f = nullptr)
             : StandardVcsLocationWidget(parent, f) {}
 
         bool isCorrect() const override
@@ -1458,16 +1455,6 @@ KDevelop::VcsLocationWidget* GitPlugin::vcsLocation(QWidget* parent) const
     return new GitVcsLocationWidget(parent);
 }
 
-bool GitPlugin::hasError() const
-{
-    return m_hasError;
-}
-
-QString GitPlugin::errorDescription() const
-{
-    return m_errorDescription;
-}
-
 void GitPlugin::registerRepositoryForCurrentBranchChanges(const QUrl& repository)
 {
     QDir dir = dotGitDirectory(repository);
