@@ -75,7 +75,7 @@ static QString patternFromSelection(const KDevelop::IDocument* doc)
 }
 
 GrepViewPlugin::GrepViewPlugin( QObject *parent, const QVariantList & )
-    : KDevelop::IPlugin( QStringLiteral("kdevgrepview"), parent ), m_currentJob(0)
+    : KDevelop::IPlugin( QStringLiteral("kdevgrepview"), parent ), m_currentJob(nullptr)
 {
     setXMLFile(QStringLiteral("kdevgrepview.rc"));
 
@@ -113,10 +113,10 @@ void GrepViewPlugin::unload()
 {
     core()->uiController()->removeToolView(m_factory);
 }
-void GrepViewPlugin::startSearch(QString pattern, QString directory, bool showOptions)
+void GrepViewPlugin::startSearch(QString pattern, QString directory, bool show)
 {
     m_directory = directory;
-    showDialog(false, pattern, showOptions);
+    showDialog(false, pattern, show);
 }
 
 KDevelop::ContextMenuExtension GrepViewPlugin::contextMenuExtension(KDevelop::Context* context)
@@ -127,7 +127,7 @@ KDevelop::ContextMenuExtension GrepViewPlugin::contextMenuExtension(KDevelop::Co
         QList<KDevelop::ProjectBaseItem*> items = ctx->items();
         // verify if there is only one folder selected
         if ((items.count() == 1) && (items.first()->folder())) {
-            QAction* action = new QAction( i18n( "Find/Replace in This Folder" ), this );
+            QAction* action = new QAction( i18n( "Find/Replace in This Folder..." ), this );
             action->setIcon(QIcon::fromTheme(QStringLiteral("edit-find")));
             m_contextMenuDirectory = items.at(0)->folder()->path().toLocalFile();
             connect( action, &QAction::triggered, this, &GrepViewPlugin::showDialogFromProject);
@@ -138,7 +138,7 @@ KDevelop::ContextMenuExtension GrepViewPlugin::contextMenuExtension(KDevelop::Co
     if ( context->type() == KDevelop::Context::EditorContext ) {
         KDevelop::EditorContext *econtext = dynamic_cast<KDevelop::EditorContext*>(context);
         if ( econtext->view()->selection() ) {
-            QAction* action = new QAction(QIcon::fromTheme(QStringLiteral("edit-find")), i18n("&Find/Replace in Files"), this);
+            QAction* action = new QAction(QIcon::fromTheme(QStringLiteral("edit-find")), i18n("&Find/Replace in Files..."), this);
             connect(action, &QAction::triggered, this, &GrepViewPlugin::showDialogFromMenu);
             extension.addAction(KDevelop::ContextMenuExtension::ExtensionGroup, action);
         }
@@ -150,7 +150,7 @@ KDevelop::ContextMenuExtension GrepViewPlugin::contextMenuExtension(KDevelop::Co
         QMimeType mimetype = QMimeDatabase().mimeTypeForUrl(fcontext->urls().at(0));
         static const QMimeType directoryMime = QMimeDatabase().mimeTypeForName(QStringLiteral("inode/directory"));
         if (mimetype == directoryMime) {
-            QAction* action = new QAction( i18n( "Find/Replace in This Folder" ), this );
+            QAction* action = new QAction( i18n( "Find/Replace in This Folder..." ), this );
             action->setIcon(QIcon::fromTheme(QStringLiteral("edit-find")));
             m_contextMenuDirectory = fcontext->urls().at(0).toLocalFile();
             connect( action, &QAction::triggered, this, &GrepViewPlugin::showDialogFromProject);
@@ -160,20 +160,23 @@ KDevelop::ContextMenuExtension GrepViewPlugin::contextMenuExtension(KDevelop::Co
     return extension;
 }
 
-void GrepViewPlugin::showDialog(bool setLastUsed, QString pattern, bool showOptions)
+void GrepViewPlugin::showDialog(bool setLastUsed, QString pattern, bool show)
 {
     GrepDialog* dlg = new GrepDialog( this, core()->uiController()->activeMainWindow() );
+    GrepJobSettings dlgSettings = dlg->settings();
     KDevelop::IDocument* doc = core()->documentController()->activeDocument();
 
     if(!pattern.isEmpty())
     {
-        dlg->setPattern(pattern);
+        dlgSettings.pattern = pattern;
+        dlg->setSettings(dlgSettings);
     }
     else if(!setLastUsed)
     {
         QString pattern = patternFromSelection(doc);
         if (!pattern.isEmpty()) {
-            dlg->setPattern( pattern );
+            dlgSettings.pattern = pattern;
+            dlg->setSettings(dlgSettings);
         }
     }
 
@@ -182,7 +185,7 @@ void GrepViewPlugin::showDialog(bool setLastUsed, QString pattern, bool showOpti
         dlg->setSearchLocations(m_directory);
     }
 
-    if(showOptions)
+    if(show)
         dlg->show();
     else{
         dlg->startSearch();
@@ -208,7 +211,7 @@ void GrepViewPlugin::rememberSearchDirectory(QString const & directory)
 
 GrepJob* GrepViewPlugin::newGrepJob()
 {
-    if(m_currentJob != 0)
+    if(m_currentJob != nullptr)
     {
         m_currentJob->kill();
     }
@@ -227,6 +230,6 @@ void GrepViewPlugin::jobFinished(KJob* job)
     if(job == m_currentJob)
     {
         emit grepJobFinished();
-        m_currentJob = 0;
+        m_currentJob = nullptr;
     }
 }
