@@ -118,7 +118,9 @@ void PatchReviewPlugin::seekHunk( bool forwards, const QUrl& fileName ) {
                             return;
                         } else if(fileName.isEmpty()) {
                             int next = qBound(0, forwards ? a+1 : a-1, m_modelList->modelCount()-1);
-                            ICore::self()->documentController()->openDocument(urlForFileModel(m_modelList->modelAt(next)));
+                            if (next < maximumFilesToOpenDirectly) {
+                                ICore::self()->documentController()->openDocument(urlForFileModel(m_modelList->modelAt(next)));
+                            }
                         }
                     }
                 }
@@ -160,7 +162,7 @@ void PatchReviewPlugin::addHighlighting( const QUrl& highlightFile, IDocument* d
 
             removeHighlighting( file );
 
-            m_highlighters[file] = new PatchHighlighter( model, doc, this );
+            m_highlighters[file] = new PatchHighlighter( model, doc, this, dynamic_cast<LocalPatchSource*>(m_patch.data()) == nullptr );
         }
     } catch ( const QString & str ) {
         qCDebug(PLUGIN_PATCHREVIEW) << "highlightFile():" << str;
@@ -254,7 +256,7 @@ void PatchReviewPlugin::updateKompareModel() {
 
     if (!patchFile.isEmpty()) //only try to construct the model if we have a patch to load
     try {
-        m_diffSettings = new DiffSettings( 0 );
+        m_diffSettings = new DiffSettings( nullptr );
         m_kompareInfo.reset( new Kompare::Info() );
         m_kompareInfo->localDestination = patchFile;
         m_kompareInfo->localSource = m_patch->baseDir().toLocalFile();
@@ -297,9 +299,9 @@ void PatchReviewPlugin::updateKompareModel() {
 
         return;
     } catch ( const QString & str ) {
-        KMessageBox::error( 0, str, i18n( "Kompare Model Update" ) );
+        KMessageBox::error( nullptr, str, i18n( "Kompare Model Update" ) );
     } catch ( const char * str ) {
-        KMessageBox::error( 0, str, i18n( "Kompare Model Update" ) );
+        KMessageBox::error( nullptr, str, i18n( "Kompare Model Update" ) );
     }
     removeHighlighting();
     m_modelList.reset( nullptr );
@@ -317,7 +319,7 @@ class PatchReviewToolViewFactory : public KDevelop::IToolViewFactory
 public:
     PatchReviewToolViewFactory( PatchReviewPlugin *plugin ) : m_plugin( plugin ) {}
 
-    QWidget* create( QWidget *parent = 0 ) override {
+    QWidget* create( QWidget *parent = nullptr ) override {
         return new PatchReviewToolView( parent, m_plugin );
     }
 
@@ -340,7 +342,7 @@ PatchReviewPlugin::~PatchReviewPlugin()
     // Tweak to work around a crash on OS X; see https://bugs.kde.org/show_bug.cgi?id=338829
     // and http://qt-project.org/forums/viewthread/38406/#162801
     // modified tweak: use setPatch() and deleteLater in that method.
-    setPatch(0);
+    setPatch(nullptr);
 }
 
 void PatchReviewPlugin::clearPatch( QObject* _patch ) {
@@ -356,8 +358,17 @@ void PatchReviewPlugin::clearPatch( QObject* _patch ) {
 void PatchReviewPlugin::closeReview()
 {
     if( m_patch ) {
+        IDocument* patchDocument = ICore::self()->documentController()->documentForUrl( m_patch->file() );
+        if (patchDocument) {
+            // Revert modifications to the text document which we've done in updateReview
+            patchDocument->setPrettyName( QString() );
+            patchDocument->textDocument()->setReadWrite( true );
+            KTextEditor::ModificationInterface* modif = dynamic_cast<KTextEditor::ModificationInterface*>( patchDocument->textDocument() );
+            modif->setModifiedOnDiskWarning( true );
+        }
+
         removeHighlighting();
-        m_modelList.reset( 0 );
+        m_modelList.reset( nullptr );
         m_depth = 0;
 
         if( !dynamic_cast<LocalPatchSource*>( m_patch.data() ) ) {
@@ -366,8 +377,8 @@ void PatchReviewPlugin::closeReview()
         } else
             emit patchChanged();
 
-        Sublime::MainWindow* w = dynamic_cast<Sublime::MainWindow*>( ICore::self()->uiController()->activeMainWindow() );
-        if( w->area()->objectName() == QLatin1String("review") ) {
+        Sublime::Area* area = ICore::self()->uiController()->activeArea();
+        if( area->objectName() == QLatin1String("review") ) {
             if( ICore::self()->documentController()->saveAllDocuments() )
                 ICore::self()->uiController()->switchToArea( QStringLiteral("code"), KDevelop::IUiController::ThisWindow );
         }
@@ -430,49 +441,45 @@ void PatchReviewPlugin::updateReview()
 
     switchToEmptyReviewArea();
 
-    IDocument* futureActiveDoc = ICore::self()->documentController()->openDocument( m_patch->file() );
+    KDevelop::IDocumentController *docController = ICore::self()->documentController();
+    // don't add documents opened automatically to the Files/Open Recent list
+    IDocument* futureActiveDoc = docController->openDocument( m_patch->file(), KTextEditor::Range::invalid(),
+                                                              IDocumentController::DoNotAddToRecentOpen );
 
     updateKompareModel();
+
     if ( !m_modelList || !futureActiveDoc || !futureActiveDoc->textDocument() ) {
         // might happen if e.g. openDocument dialog was cancelled by user
         // or under the theoretic possibility of a non-text document getting opened
         return;
     }
+
     futureActiveDoc->textDocument()->setReadWrite( false );
     futureActiveDoc->setPrettyName( i18n( "Overview" ) );
-
-    IDocument* buddyDoc = futureActiveDoc;
-
     KTextEditor::ModificationInterface* modif = dynamic_cast<KTextEditor::ModificationInterface*>( futureActiveDoc->textDocument() );
     modif->setModifiedOnDiskWarning( false );
 
-    if( m_modelList->modelCount() < maximumFilesToOpenDirectly ) {
-        //Open all relates files
-        for( int a = 0; a < m_modelList->modelCount(); ++a ) {
-            QUrl absoluteUrl = urlForFileModel( m_modelList->modelAt( a ) );
-            if (absoluteUrl.isRelative()) {
-                KMessageBox::error( 0, i18n("The base directory of the patch must be an absolute directory"), i18n( "Patch Review" ) );
-                break;
-            }
+    docController->activateDocument( futureActiveDoc );
 
-            if( QFileInfo::exists( absoluteUrl.toLocalFile() ) && absoluteUrl.toLocalFile() != QLatin1String("/dev/null") )
-            {
-                buddyDoc = ICore::self()->documentController()->openDocument( absoluteUrl, KTextEditor::Range::invalid(), IDocumentController::DoNotActivate, QLatin1String(""), buddyDoc );
+    PatchReviewToolView* toolView = qobject_cast<PatchReviewToolView*>(ICore::self()->uiController()->findToolView( i18n( "Patch Review" ), m_factory ));
+    Q_ASSERT( toolView );
 
-                seekHunk( true, absoluteUrl ); //Jump to the first changed position
-            }else{
-                // Maybe the file was deleted
-                qCDebug(PLUGIN_PATCHREVIEW) << "could not open" << absoluteUrl << "because it doesn't exist";
-            }
+    //Open all relates files
+    for( int a = 0; a < m_modelList->modelCount() && a < maximumFilesToOpenDirectly; ++a ) {
+        QUrl absoluteUrl = urlForFileModel( m_modelList->modelAt( a ) );
+        if (absoluteUrl.isRelative()) {
+            KMessageBox::error( nullptr, i18n("The base directory of the patch must be an absolute directory"), i18n( "Patch Review" ) );
+            break;
+        }
+
+        if( QFileInfo::exists( absoluteUrl.toLocalFile() ) && absoluteUrl.toLocalFile() != QLatin1String("/dev/null") )
+        {
+            toolView->open( absoluteUrl, false );
+        }else{
+            // Maybe the file was deleted
+            qCDebug(PLUGIN_PATCHREVIEW) << "could not open" << absoluteUrl << "because it doesn't exist";
         }
     }
-
-    Q_ASSERT( futureActiveDoc );
-    ICore::self()->documentController()->activateDocument( futureActiveDoc );
-
-    bool b = ICore::self()->uiController()->findToolView( i18n( "Patch Review" ), m_factory );
-    Q_ASSERT( b );
-    Q_UNUSED( b );
 }
 
 void PatchReviewPlugin::setPatch( IPatchSource* patch ) {
@@ -506,8 +513,8 @@ void PatchReviewPlugin::setPatch( IPatchSource* patch ) {
 
 PatchReviewPlugin::PatchReviewPlugin( QObject *parent, const QVariantList & )
     : KDevelop::IPlugin( QStringLiteral("kdevpatchreview"), parent ),
-    m_patch( 0 ), m_factory( new PatchReviewToolViewFactory( this ) ) {
-    KDEV_USE_EXTENSION_INTERFACE( KDevelop::IPatchReview )
+    m_patch( nullptr ), m_factory( new PatchReviewToolViewFactory( this ) )
+{
     qRegisterMetaType<const Diff2::DiffModel*>( "const Diff2::DiffModel*" );
 
     setXMLFile( QStringLiteral("kdevpatchreview.rc") );
@@ -543,7 +550,10 @@ void PatchReviewPlugin::documentSaved( IDocument* doc ) {
     // Only update if the url is not the patch-file, because our call to
     // the reload() KTextEditor function also causes this signal,
     // which would lead to an endless update loop.
-    if( m_patch && doc->url() != m_patch->file() )
+    // Also, don't automatically update local patch sources, because
+    // they may correspond to static files which don't match any more
+    // after an edit was done.
+    if( m_patch && doc->url() != m_patch->file() && !dynamic_cast<LocalPatchSource*>(m_patch.data()) )
         forceUpdate();
 }
 
