@@ -100,11 +100,15 @@ void ProblemHighlighter::setProblems(const QVector<IProblem::Ptr>& problems)
     if (!m_document)
         return;
 
+    if (m_problems == problems)
+        return;
+
     const bool hadProblems = !m_problems.isEmpty();
     m_problems = problems;
 
     qDeleteAll(m_topHLRanges);
     m_topHLRanges.clear();
+    m_problemsForRanges.clear();
 
     IndexedString url(m_document->url());
 
@@ -145,6 +149,29 @@ void ProblemHighlighter::setProblems(const QVector<IProblem::Ptr>& problems)
         else
             range = problem->finalLocation();
 
+        // Fix problem's location range if necessary
+        if (problem->finalLocationMode() != IProblem::Range && range.onSingleLine()) {
+            int line = range.start().line();
+            const QString lineString = m_document->line(line);
+
+            int startColumn = 0;
+            int endColumn = lineString.length() - 1;
+
+            if (problem->finalLocationMode() == IProblem::TrimmedLine) {
+                while (lineString.at(startColumn++).isSpace()) {}
+                --startColumn;
+
+                while (lineString.at(endColumn--).isSpace()) {}
+                ++endColumn;
+            }
+
+            range.setStart(Cursor(line, startColumn));
+            range.setEnd(Cursor(line, endColumn));
+
+            problem->setFinalLocation(DocumentRange(problem->finalLocation().document, range));
+            problem->setFinalLocationMode(IProblem::Range);
+        }
+
         if (range.end().line() >= m_document->lines())
             range.end() = KTextEditor::Cursor(m_document->endOfLine(m_document->lines() - 1));
 
@@ -153,6 +180,8 @@ void ProblemHighlighter::setProblems(const QVector<IProblem::Ptr>& problems)
         }
 
         KTextEditor::MovingRange* problemRange = iface->newMovingRange(range);
+
+        m_problemsForRanges.insert(problemRange, problem);
         m_topHLRanges.append(problemRange);
 
         if (problem->source() != IProblem::ToDo
@@ -187,6 +216,7 @@ void ProblemHighlighter::aboutToRemoveText(const KTextEditor::Range& range)
     QList<MovingRange*>::iterator it = m_topHLRanges.begin();
     while (it != m_topHLRanges.end()) {
         if (range.contains((*it)->toRange())) {
+            m_problemsForRanges.remove(*it);
             delete (*it);
             it = m_topHLRanges.erase(it);
         } else {
