@@ -66,7 +66,7 @@ using namespace KDevelop;
 class ProblemReporterFactory : public KDevelop::IToolViewFactory
 {
 public:
-    QWidget* create(QWidget* parent = 0) override
+    QWidget* create(QWidget* parent = nullptr) override
     {
         Q_UNUSED(parent);
 
@@ -86,7 +86,7 @@ ProblemReporterPlugin::ProblemReporterPlugin(QObject* parent, const QVariantList
     , m_model(new ProblemReporterModel(this))
 {
     KDevelop::ProblemModelSet* pms = core()->languageController()->problemModelSet();
-    pms->addModel(QStringLiteral("Parser"), m_model);
+    pms->addModel(QStringLiteral("Parser"), i18n("Parser"), m_model);
     core()->uiController()->addToolView(i18n("Problems"), m_factory);
     setXMLFile(QStringLiteral("kdevproblemreporter.rc"));
 
@@ -94,10 +94,14 @@ ProblemReporterPlugin::ProblemReporterPlugin(QObject* parent, const QVariantList
             &ProblemReporterPlugin::documentClosed);
     connect(ICore::self()->documentController(), &IDocumentController::textDocumentCreated, this,
             &ProblemReporterPlugin::textDocumentCreated);
+    connect(ICore::self()->documentController(), &IDocumentController::documentActivated, this,
+            &ProblemReporterPlugin::documentActivated);
     connect(DUChain::self(), &DUChain::updateReady,
             this, &ProblemReporterPlugin::updateReady);
     connect(ICore::self()->languageController()->staticAssistantsManager(), &StaticAssistantsManager::problemsChanged,
             this, &ProblemReporterPlugin::updateHighlight);
+    connect(pms, &ProblemModelSet::showRequested, this, &ProblemReporterPlugin::showModel);
+    connect(pms, &ProblemModelSet::problemsChanged, this, &ProblemReporterPlugin::updateOpenedDocumentsHighlight);
 }
 
 ProblemReporterPlugin::~ProblemReporterPlugin()
@@ -125,6 +129,7 @@ void ProblemReporterPlugin::documentClosed(IDocument* doc)
 
     IndexedString url(doc->url());
     delete m_highlighters.take(url);
+    m_reHighlightNeeded.remove(url);
 }
 
 void ProblemReporterPlugin::textDocumentCreated(KDevelop::IDocument* document)
@@ -135,6 +140,16 @@ void ProblemReporterPlugin::textDocumentCreated(KDevelop::IDocument* document)
                                          KDevelop::TopDUContext::AllDeclarationsContextsAndUses, this);
 }
 
+void ProblemReporterPlugin::documentActivated(KDevelop::IDocument* document)
+{
+  IndexedString documentUrl(document->url());
+
+  if (m_reHighlightNeeded.contains(documentUrl)) {
+    m_reHighlightNeeded.remove(documentUrl);
+    updateHighlight(documentUrl);
+  }
+}
+
 void ProblemReporterPlugin::updateReady(const IndexedString& url, const KDevelop::ReferencedTopDUContext&)
 {
     m_model->problemsUpdated(url);
@@ -143,11 +158,25 @@ void ProblemReporterPlugin::updateReady(const IndexedString& url, const KDevelop
 
 void ProblemReporterPlugin::updateHighlight(const KDevelop::IndexedString& url)
 {
-  ProblemHighlighter* ph = m_highlighters.value(url);
-    if (ph) {
-        auto allProblems = m_model->problems(url, false);
-        ph->setProblems(allProblems);
+    ProblemHighlighter* ph = m_highlighters.value(url);
+    if (!ph)
+        return;
+
+    KDevelop::ProblemModelSet* pms(core()->languageController()->problemModelSet());
+    QVector<IProblem::Ptr> documentProblems;
+
+    foreach (const ModelData& modelData, pms->models()) {
+        documentProblems += modelData.model->problems({url});
     }
+
+    ph->setProblems(documentProblems);
+}
+
+void ProblemReporterPlugin::showModel(const QString& id)
+{
+    auto w = dynamic_cast<ProblemsView*>(core()->uiController()->findToolView(i18n("Problems"), m_factory));
+    if (w)
+      w->showModel(id);
 }
 
 KDevelop::ContextMenuExtension ProblemReporterPlugin::contextMenuExtension(KDevelop::Context* context)
@@ -188,8 +217,8 @@ KDevelop::ContextMenuExtension ProblemReporterPlugin::contextMenuExtension(KDeve
                 text = i18n("Solve: %1", KDevelop::htmlToPlainText(title));
             }
 
-            QAction* menuAction = new QAction(text, 0);
-            QMenu* menu(new QMenu(text, 0));
+            QAction* menuAction = new QAction(text, nullptr);
+            QMenu* menu(new QMenu(text, nullptr));
             menuAction->setMenu(menu);
             foreach (QAction* action, actions)
                 menu->addAction(action);
@@ -200,6 +229,26 @@ KDevelop::ContextMenuExtension ProblemReporterPlugin::contextMenuExtension(KDeve
     return extension;
 }
 
+void ProblemReporterPlugin::updateOpenedDocumentsHighlight()
+{
+    foreach(auto document, core()->documentController()->openDocuments()) {
+        // Skip non-text documents.
+        // This also fixes crash caused by calling updateOpenedDocumentsHighlight() method without
+        // any opened documents. In this case documentController()->openDocuments() returns single
+        // (non-text) document with url like file:///tmp/kdevelop_QW2530.patch which has fatal bug:
+        // if we call isActive() method from this document the crash will happens.
+        if (!document->isTextDocument())
+            continue;
+
+        IndexedString documentUrl(document->url());
+
+        if (document->isActive())
+            updateHighlight(documentUrl);
+        else
+            m_reHighlightNeeded.insert(documentUrl);
+    }
+}
+
 #include "problemreporterplugin.moc"
 
 // kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
