@@ -26,7 +26,6 @@
 
 namespace KDevelop
 {
-class ParseJob;
 class TopDUContext;
 class IDocument;
 class ProblemModel;
@@ -51,6 +50,8 @@ public:
                              const QVector<int>& roles = QVector<int>()) override;
     void reset() override;
 
+    int setFilter(const QString& filterText);
+
 public slots:
     void openDocumentForCurrentProblem();
 
@@ -64,8 +65,6 @@ protected:
 private slots:
     void itemActivated(const QModelIndex& index);
 
-    void setScope(int scope);
-
 private:
     void resizeColumns();
     ProblemReporterPlugin* m_plugin;
