@@ -75,6 +75,7 @@ ProjectManagerView::ProjectManagerView( ProjectManagerViewPlugin* plugin, QWidge
         : QWidget( parent ), m_ui(new Ui::ProjectManagerView), m_plugin(plugin)
 {
     m_ui->setupUi( this );
+    setFocusProxy(m_ui->projectTreeView);
 
     m_ui->projectTreeView->installEventFilter(this);
 
@@ -172,7 +173,7 @@ void ProjectManagerView::selectionChanged()
     {
         selected << ICore::self()->projectController()->projectModel()->itemFromIndex(indexFromView( idx ));
     }
-    selected.removeAll(0);
+    selected.removeAll(nullptr);
     KDevelop::ICore::self()->selectionController()->updateSelection( new ProjectManagerViewItemContext( selected, this ) );
 }
 
