@@ -26,20 +26,15 @@
 
 class SvnImportInternalJob;
 
-class SvnImportJob : public SvnJobBase
+class SvnImportJob : public SvnJobBaseImpl<SvnImportInternalJob>
 {
     Q_OBJECT
 public:
-    SvnImportJob( KDevSvnPlugin* parent );
-    QVariant fetchResults();
-    void start();
-    SvnInternalJobBase* internalJob() const;
-
-    void setMapping( const KUrl & sourceDirectory, const KDevelop::VcsLocation & destinationRepository);
+    explicit SvnImportJob( KDevSvnPlugin* parent );
+    QVariant fetchResults() override;
+    void start() override;
+    void setMapping( const QUrl &sourceDirectory, const KDevelop::VcsLocation & destinationRepository);
     void setMessage( const QString& );
-private:
-    SvnImportInternalJob* m_job;
-
 };
 
 
