@@ -107,6 +107,8 @@ TestView::TestView(TestViewPlugin* plugin, QWidget* parent)
     connect(edit, &QLineEdit::textChanged, this, &TestView::changeFilter);
     addAction(widgetAction);
 
+    setFocusProxy(edit);
+
     IProjectController* pc = ICore::self()->projectController();
     connect (pc, &IProjectController::projectClosed, this, &TestView::removeProject);
 
@@ -232,16 +234,15 @@ QStandardItem* TestView::itemForSuite(ITestSuite* suite)
             return item;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 QStandardItem* TestView::itemForProject(IProject* project)
 {
-    foreach (QStandardItem* item, m_model->findItems(project->name()))
-    {
-        return item;
+    QList<QStandardItem*> itemsForProject = m_model->findItems(project->name());
+    if (!itemsForProject.isEmpty()) {
+        return itemsForProject.first();
     }
-
     return addProject(project);
 }
 
@@ -278,7 +279,7 @@ void TestView::runSelectedTests()
             continue;
         }
         QStandardItem* item = m_model->itemFromIndex(index);
-        if (item->parent() == 0)
+        if (item->parent() == nullptr)
         {
             // A project was selected
             IProject* project = ICore::self()->projectController()->findProjectByName(item->data(ProjectRole).toString());
@@ -287,7 +288,7 @@ void TestView::runSelectedTests()
                 jobs << suite->launchAllCases(ITestSuite::Silent);
             }
         }
-        else if (item->parent()->parent() == 0)
+        else if (item->parent()->parent() == nullptr)
         {
             // A suite was selected
             IProject* project = ICore::self()->projectController()->findProjectByName(item->parent()->data(ProjectRole).toString());
@@ -326,12 +327,12 @@ void TestView::showSource()
 
     QModelIndex index = m_filter->mapToSource(indexes.first());
     QStandardItem* item = m_model->itemFromIndex(index);
-    if (item->parent() == 0)
+    if (item->parent() == nullptr)
     {
         // No sense in finding source code for projects.
         return;
     }
-    else if (item->parent()->parent() == 0)
+    else if (item->parent()->parent() == nullptr)
     {
         IProject* project = ICore::self()->projectController()->findProjectByName(item->parent()->data(ProjectRole).toString());
         ITestSuite* suite =  tc->findTestSuite(project, item->data(SuiteRole).toString());
