@@ -74,7 +74,11 @@ struct AbstractFileManagerPlugin::Private {
 
     AbstractFileManagerPlugin* q;
 
-    KIO::Job* eventuallyReadFolder( ProjectFolderItem* item );
+    /**
+     * The just returned must be started in one way or another for this method
+     * to have any affect. The job will then auto-delete itself upon completion.
+     */
+    KIO::Job* eventuallyReadFolder( ProjectFolderItem* item ) Q_REQUIRED_RESULT;
     void addJobItems(FileManagerListJob* job,
                      ProjectFolderItem* baseItem,
                      const KIO::UDSEntryList& entries);
@@ -266,7 +270,8 @@ void AbstractFileManagerPlugin::Private::created(const QString &path_)
                 // exists already in this project, happens e.g. when we restart the dirwatcher
                 // or if we delete and remove folders consecutively https://bugs.kde.org/show_bug.cgi?id=260741
                 qCDebug(FILEMANAGER) << "force reload of" << path << folder;
-                eventuallyReadFolder( folder );
+                auto job = eventuallyReadFolder( folder );
+                job->start();
                 found = true;
             }
             if ( found ) {
@@ -281,7 +286,8 @@ void AbstractFileManagerPlugin::Private::created(const QString &path_)
                 ProjectFolderItem* folder = q->createFolderItem( p, path, parentItem );
                 if (folder) {
                     emit q->folderAdded( folder );
-                    eventuallyReadFolder( folder );
+                    auto job = eventuallyReadFolder( folder );
+                    job->start();
                 }
             } else {
                 ProjectFileItem* file = q->createFileItem( p, path, parentItem );
@@ -432,8 +438,6 @@ AbstractFileManagerPlugin::AbstractFileManagerPlugin( const QString& componentNa
       IPlugin( componentName, parent ),
       d(new Private(this))
 {
-    KDEV_USE_EXTENSION_INTERFACE( IProjectFileManager )
-
     connect(core()->projectController(), &IProjectController::projectClosing,
             this, [&] (IProject* project) { d->projectClosing(project); });
 }
@@ -458,7 +462,7 @@ QList<ProjectFolderItem*> AbstractFileManagerPlugin::parse( ProjectFolderItem *i
 
 ProjectFolderItem *AbstractFileManagerPlugin::import( IProject *project )
 {
-    ProjectFolderItem *projectRoot = createFolderItem( project, project->path(), 0 );
+    ProjectFolderItem *projectRoot = createFolderItem( project, project->path(), nullptr );
     emit folderAdded( projectRoot );
     qCDebug(FILEMANAGER) << "imported new project" << project->name() << "at" << projectRoot->path();
 
@@ -487,7 +491,8 @@ KJob* AbstractFileManagerPlugin::createImportJob(ProjectFolderItem* item)
 bool AbstractFileManagerPlugin::reload( ProjectFolderItem* item )
 {
     qCDebug(FILEMANAGER) << "reloading item" << item->path();
-    d->eventuallyReadFolder( item->folder() );
+    auto job = d->eventuallyReadFolder( item->folder() );
+    job->start();
     return true;
 }
 
@@ -495,7 +500,7 @@ ProjectFolderItem* AbstractFileManagerPlugin::addFolder( const Path& folder,
         ProjectFolderItem * parent )
 {
     qCDebug(FILEMANAGER) << "adding folder" << folder << "to" << parent->path();
-    ProjectFolderItem* created = 0;
+    ProjectFolderItem* created = nullptr;
     d->stopWatcher(parent);
     if ( createFolder(folder.toUrl()) ) {
         created = createFolderItem( parent->project(), folder, parent );
@@ -512,7 +517,7 @@ ProjectFileItem* AbstractFileManagerPlugin::addFile( const Path& file,
         ProjectFolderItem * parent )
 {
     qCDebug(FILEMANAGER) << "adding file" << file << "to" << parent->path();
-    ProjectFileItem* created = 0;
+    ProjectFileItem* created = nullptr;
     d->stopWatcher(parent);
     if ( createFile(file.toUrl()) ) {
         created = createFileItem( parent->project(), file, parent );
@@ -644,7 +649,7 @@ ProjectFolderItem* AbstractFileManagerPlugin::createFolderItem( IProject* projec
 
 KDirWatch* AbstractFileManagerPlugin::projectWatcher( IProject* project ) const
 {
-    return d->m_watchers.value( project, 0 );
+    return d->m_watchers.value( project, nullptr );
 }
 
 //END Plugin
