@@ -46,6 +46,8 @@ ProjectConfigSkeleton::ProjectConfigSkeleton( const QString & configname )
 ProjectConfigSkeleton::ProjectConfigSkeleton( KSharedConfigPtr config )
         : KConfigSkeleton( config ), d( new ProjectConfigSkeletonPrivate )
 {
+    Q_ASSERT(config);
+    d->m_developerTempFile = config->name();
 }
 
 void ProjectConfigSkeleton::setDeveloperTempFile( const QString& cfg )
