@@ -70,19 +70,19 @@ ProjectModelPerformanceTest::ProjectModelPerformanceTest(QWidget* parent )
     // This is used so the treeview layout performance is not influencing the test
     view->setUniformRowHeights( true );
 
-    QPushButton* b = new QPushButton( "Expand All", this );
+    QPushButton* b = new QPushButton( QStringLiteral("Expand All"), this );
     connect( b, &QPushButton::clicked, view, &QTreeView::expandAll );
     l->addWidget( b, 0, 0 );
-    b = new QPushButton( "Collapse All", this );
+    b = new QPushButton( QStringLiteral("Collapse All"), this );
     connect( b, &QPushButton::clicked, view, &QTreeView::collapseAll );
     l->addWidget( b, 0, 1 );
-    b = new QPushButton( "Add Small Subtree", this );
+    b = new QPushButton( QStringLiteral("Add Small Subtree"), this );
     connect( b, &QPushButton::clicked, this, &ProjectModelPerformanceTest::addSmallTree );
     l->addWidget( b, 0, 2 );
-    b = new QPushButton( "Add Big Subtree", this );
+    b = new QPushButton( QStringLiteral("Add Big Subtree"), this );
     connect( b, &QPushButton::clicked, this, &ProjectModelPerformanceTest::addBigTree );
     l->addWidget( b, 0, 3 );
-    b = new QPushButton( "Add Big Subtree in Chunks", this );
+    b = new QPushButton( QStringLiteral("Add Big Subtree in Chunks"), this );
     connect( b, &QPushButton::clicked, this, &ProjectModelPerformanceTest::addBigTreeDelayed );
     l->addWidget( b, 0, 4 );
 
@@ -107,7 +107,7 @@ void ProjectModelPerformanceTest::init()
     timer.start();
 
     for( int i = 0; i < INIT_WIDTH; i++ ) {
-        ProjectFolderItem* item = new ProjectFolderItem( 0, Path( QUrl::fromLocalFile( QStringLiteral( "/f%1" ).arg( i ) ) ) );
+        ProjectFolderItem* item = new ProjectFolderItem( nullptr, Path( QUrl::fromLocalFile( QStringLiteral( "/f%1" ).arg( i ) ) ) );
         generateChilds( item, INIT_WIDTH, INIT_DEPTH );
         model->appendRow( item );
     }
@@ -132,7 +132,7 @@ void ProjectModelPerformanceTest::addBigTree()
     QElapsedTimer timer;
     timer.start();
     for( int i = 0; i < BIG_WIDTH; i++ ) {
-        ProjectFolderItem* item = new ProjectFolderItem( 0, Path( QUrl::fromLocalFile( QStringLiteral( "/f%1" ).arg( i ) ) ) );
+        ProjectFolderItem* item = new ProjectFolderItem( nullptr, Path( QUrl::fromLocalFile( QStringLiteral( "/f%1" ).arg( i ) ) ) );
         generateChilds( item, BIG_WIDTH, BIG_DEPTH );
         model->appendRow( item );
     }
@@ -149,7 +149,7 @@ void ProjectModelPerformanceTest::addItemDelayed()
 {
     QElapsedTimer timer;
     timer.start();
-    ProjectBaseItem* parent = 0;
+    ProjectBaseItem* parent = nullptr;
     Path path;
     if( !currentParent.isEmpty() ) {
         parent = currentParent.top();
@@ -157,11 +157,11 @@ void ProjectModelPerformanceTest::addItemDelayed()
     } else {
         path = Path(QUrl::fromLocalFile(QStringLiteral("/f%1").arg(model->rowCount())));
     }
-    ProjectBaseItem* item = 0;
+    ProjectBaseItem* item = nullptr;
     if( currentParent.size() < BIG_DEPTH ) {
-        item = new ProjectFolderItem(0, path, parent);
+        item = new ProjectFolderItem(nullptr, path, parent);
     } else {
-        item = new ProjectFileItem( 0, path, parent );
+        item = new ProjectFileItem( nullptr, path, parent );
     }
     if( currentParent.isEmpty() ) {
         model->appendRow( item );
@@ -187,7 +187,7 @@ void ProjectModelPerformanceTest::addSmallTree()
     QElapsedTimer timer;
     timer.start();
     for( int i = 0; i < SMALL_WIDTH; i++ ) {
-        ProjectFolderItem* item = new ProjectFolderItem( 0, Path(QUrl::fromLocalFile( QStringLiteral( "/f%1" ).arg( i ) )) );
+        ProjectFolderItem* item = new ProjectFolderItem( nullptr, Path(QUrl::fromLocalFile( QStringLiteral( "/f%1" ).arg( i ) )) );
         generateChilds( item, SMALL_WIDTH, SMALL_DEPTH );
         model->appendRow( item );
     }
