@@ -130,12 +130,12 @@ class Bucket {
     Bucket()
       : m_monsterBucketExtent(0)
       , m_available(0)
-      , m_data(0)
-      , m_mappedData(0)
-      , m_objectMap(0)
+      , m_data(nullptr)
+      , m_mappedData(nullptr)
+      , m_objectMap(nullptr)
       , m_largestFreeItem(0)
       , m_freeItemCount(0)
-      , m_nextBucketHash(0)
+      , m_nextBucketHash(nullptr)
       , m_dirty(false)
       , m_changed(false)
       , m_lastUsed(0)
@@ -214,7 +214,7 @@ class Bucket {
 
       if(static_cast<size_t>(file->pos()) != offset + (1+m_monsterBucketExtent)*DataSize)
       {
-        KMessageBox::error(0, i18n("Failed writing to %1, probably the disk is full", file->fileName()));
+        KMessageBox::error(nullptr, i18n("Failed writing to %1, probably the disk is full", file->fileName()));
         abort();
       }
 
@@ -1013,7 +1013,7 @@ class DynamicItem {
     DynamicItem(const DynamicItem& rhs) : m_item(rhs.m_item), m_start(rhs.m_start) {
 //         qDebug() << "stealing" << m_item;
       Q_ASSERT(rhs.m_start);
-      rhs.m_start = 0;
+      rhs.m_start = nullptr;
     }
 
     Item* operator->() {
@@ -1026,14 +1026,14 @@ class DynamicItem {
     DynamicItem& operator=(const DynamicItem&);
 };
 
-///@param Item @see ExampleItem
-///@param ItemRequest @see ExampleReqestItem
-///@param fixedItemSize When this is true, all inserted items must have the same size.
+///@tparam Item See ExampleItem
+///@tparam ItemRequest See ExampleReqestItem
+///@tparam fixedItemSize When this is true, all inserted items must have the same size.
 ///                     This greatly simplifies and speeds up the task of managing free items within the buckets.
-///@param markForReferenceCounting Whether the data within the repository should be marked for reference-counting.
+///@tparam markForReferenceCounting Whether the data within the repository should be marked for reference-counting.
 ///                                This costs a bit of performance, but must be enabled if there may be data in the repository
 ///                                that does on-disk reference counting, like IndexedString, IndexedIdentifier, etc.
-///@param threadSafe Whether class access should be thread-safe. Disabling this is dangerous when you do multi-threading.
+///@tparam threadSafe Whether class access should be thread-safe. Disabling this is dangerous when you do multi-threading.
 ///                  You have to make sure that mutex() is locked whenever the repository is accessed.
 template<class Item, class ItemRequest, bool markForReferenceCounting = true, bool threadSafe = true, uint fixedItemSize = 0, unsigned int targetBucketHashSize = 524288*2>
 class ItemRepository : public AbstractItemRepository {
@@ -1057,20 +1057,20 @@ class ItemRepository : public AbstractItemRepository {
   ///                If this is zero, you have to care about storing the data using store() and/or close() by yourself. It does not happen automatically.
   ///                For the global standard registry, the storing/loading is triggered from within duchain, so you don't need to care about it.
   ItemRepository(const QString& repositoryName, ItemRepositoryRegistry* registry  = &globalItemRepositoryRegistry(),
-                 uint repositoryVersion = 1, AbstractRepositoryManager* manager = 0)
+                 uint repositoryVersion = 1, AbstractRepositoryManager* manager = nullptr)
     : m_ownMutex(QMutex::Recursive)
     , m_mutex(&m_ownMutex)
     , m_repositoryName(repositoryName)
     , m_registry(registry)
-    , m_file(0)
-    , m_dynamicFile(0)
+    , m_file(nullptr)
+    , m_dynamicFile(nullptr)
     , m_repositoryVersion(repositoryVersion)
     , m_manager(manager)
   {
     m_unloadingEnabled = true;
     m_metaDataChanged = true;
     m_buckets.resize(10);
-    m_buckets.fill(0);
+    m_buckets.fill(nullptr);
 
     memset(m_firstBucketForHash, 0, bucketHashSize * sizeof(short unsigned int));
 
@@ -1429,14 +1429,13 @@ class ItemRepository : public AbstractItemRepository {
     }
   }
 
+  typedef DynamicItem<Item, markForReferenceCounting> MyDynamicItem;
+
   ///This returns an editable version of the item. @warning: Never change an entry that affects the hash,
   ///or the equals(..) function. That would completely destroy the consistency.
   ///@param index The index. It must be valid(match an existing item), and nonzero.
   ///@warning If you use this, make sure you lock mutex() before calling,
   ///         and hold it until you're ready using/changing the data..
-
-  typedef DynamicItem<Item, markForReferenceCounting> MyDynamicItem;
-
   MyDynamicItem dynamicItemFromIndex(unsigned int index) {
     verifyIndex(index);
 
@@ -1677,7 +1676,7 @@ class ItemRepository : public AbstractItemRepository {
 
   ///Synchronizes the state on disk to the one in memory, and does some memory-management.
   ///Should be called on a regular basis. Can be called centrally from the global item repository registry.
-  virtual void store() override {
+  void store() override {
     QMutexLocker lock(m_mutex);
     if(m_file) {
 
@@ -1695,7 +1694,7 @@ class ItemRepository : public AbstractItemRepository {
             const int unloadAfterTicks = 2;
             if(m_buckets[a]->lastUsed() > unloadAfterTicks) {
                 delete m_buckets[a];
-                m_buckets[a] = 0;
+                m_buckets[a] = nullptr;
             }else{
                 m_buckets[a]->tick();
             }
@@ -1749,7 +1748,7 @@ class ItemRepository : public AbstractItemRepository {
     m_mutex = mutex;
   }
 
-  virtual QString repositoryName() const override {
+  QString repositoryName() const override {
     return m_repositoryName;
   }
 
@@ -1900,7 +1899,7 @@ class ItemRepository : public AbstractItemRepository {
     return bucketPtr;
   }
 
-  virtual bool open(const QString& path) override {
+  bool open(const QString& path) override {
     QMutexLocker lock(m_mutex);
 
     close();
@@ -1910,9 +1909,9 @@ class ItemRepository : public AbstractItemRepository {
     m_dynamicFile = new QFile(dir.absoluteFilePath( m_repositoryName + QLatin1String("_dynamic") ));
     if(!m_file->open( QFile::ReadWrite ) || !m_dynamicFile->open( QFile::ReadWrite ) ) {
       delete m_file;
-      m_file = 0;
+      m_file = nullptr;
       delete m_dynamicFile;
-      m_dynamicFile = 0;
+      m_dynamicFile = nullptr;
       return false;
     }
 
@@ -1932,7 +1931,7 @@ class ItemRepository : public AbstractItemRepository {
       m_file->write((char*)&m_statItemCount, sizeof(uint));
 
       m_buckets.resize(10);
-      m_buckets.fill(0);
+      m_buckets.fill(nullptr);
       uint bucketCount = m_buckets.size();
       m_file->write((char*)&bucketCount, sizeof(uint));
 
@@ -1944,7 +1943,7 @@ class ItemRepository : public AbstractItemRepository {
       //We have completely initialized the file now
       if(m_file->pos() != BucketStartOffset)
       {
-        KMessageBox::error(0, i18n("Failed writing to %1, probably the disk is full", m_file->fileName()));
+        KMessageBox::error(nullptr, i18n("Failed writing to %1, probably the disk is full", m_file->fileName()));
         abort();
       }
 
@@ -1967,9 +1966,9 @@ class ItemRepository : public AbstractItemRepository {
       if(storedVersion != m_repositoryVersion || hashSize != bucketHashSize || itemRepositoryVersion != staticItemRepositoryVersion()) {
         qDebug() << "repository" << m_repositoryName << "version mismatch in" << m_file->fileName() << ", stored: version " << storedVersion << "hashsize" << hashSize << "repository-version" << itemRepositoryVersion << " current: version" << m_repositoryVersion << "hashsize" << bucketHashSize << "repository-version" << staticItemRepositoryVersion();
         delete m_file;
-        m_file = 0;
+        m_file = nullptr;
         delete m_dynamicFile;
-        m_dynamicFile = 0;
+        m_dynamicFile = nullptr;
         return false;
       }
       m_metaDataChanged = false;
@@ -1990,7 +1989,7 @@ class ItemRepository : public AbstractItemRepository {
     }
 
     m_fileMapSize = 0;
-    m_fileMap = 0;
+    m_fileMap = nullptr;
 
 #ifdef ITEMREPOSITORY_USE_MMAP_LOADING
     if(m_file->size() > BucketStartOffset){
@@ -2012,7 +2011,7 @@ class ItemRepository : public AbstractItemRepository {
   }
 
   ///@warning by default, this does not store the current state to disk.
-  virtual void close(bool doStore = false) override {
+  void close(bool doStore = false) override {
 
     if(doStore)
       store();
@@ -2020,14 +2019,14 @@ class ItemRepository : public AbstractItemRepository {
     if(m_file)
       m_file->close();
     delete m_file;
-    m_file = 0;
-    m_fileMap = 0;
+    m_file = nullptr;
+    m_fileMap = nullptr;
     m_fileMapSize = 0;
 
     if(m_dynamicFile)
       m_dynamicFile->close();
     delete m_dynamicFile;
-    m_dynamicFile = 0;
+    m_dynamicFile = nullptr;
 
     qDeleteAll(m_buckets);
     m_buckets.clear();
@@ -2066,7 +2065,7 @@ class ItemRepository : public AbstractItemRepository {
     return bucketPtr->visitAllItems(visitor);
   }
 
-  virtual int finalCleanup() override {
+  int finalCleanup() override {
     ThisLocker lock(m_mutex);
 
     int changed = 0;
@@ -2136,7 +2135,7 @@ class ItemRepository : public AbstractItemRepository {
     Q_ASSERT(bucketForIndex(bucketNumber)->isEmpty());
     Q_ASSERT(bucketForIndex(bucketNumber)->noNextBuckets());
     delete m_buckets[bucketNumber];
-    m_buckets[bucketNumber] = 0;
+    m_buckets[bucketNumber] = nullptr;
   }
 
   //m_file must be opened
