@@ -80,6 +80,8 @@ public:
 
     KTextEditor::View* activeTextDocumentView() const override;
     
+    /// Activate the given \a document. This convenience function does not add the document
+    /// to the File/Recent Open menu. Use DocumentController::openDocument if that is desired.
     void activateDocument( IDocument * document, const KTextEditor::Range& range = KTextEditor::Range::invalid() ) override;
 
     void registerDocumentForMimetype( const QString&, KDevelop::IDocumentFactory* ) override;
@@ -130,9 +132,9 @@ public Q_SLOTS:
 
     Q_SCRIPTABLE IDocument* openDocumentFromText( const QString& data ) override;
     
-    KDevelop::IDocument* openDocument( const QUrl &url, const QString& prefname ) override;
+    KDevelop::IDocument* openDocument( const QUrl &url, const QString& prefName ) override;
 
-    virtual void closeDocument( const QUrl &url );
+    virtual bool closeDocument( const QUrl &url );
     void fileClose();
     void slotSaveAllDocuments();
     bool closeAllDocuments() override;
