@@ -32,6 +32,7 @@
 #include <sublime/view.h>
 
 #include "core.h"
+#include "partcontroller.h"
 #include "uicontroller.h"
 #include "documentcontroller.h"
 #include "plugincontroller.h"
@@ -190,6 +191,12 @@ QList<KTextEditor::MainWindow *> Application::mainWindows() const
     return {activeMainWindow()};
 }
 
+bool Application::closeDocument(KTextEditor::Document *document) const
+{
+    auto documentController = Core::self()->documentControllerInternal();
+    return documentController->closeDocument(document->url());
+}
+
 KTextEditor::Plugin *Application::plugin(const QString &id) const
 {
     auto kdevPlugin = Core::self()->pluginController()->loadPlugin(id);
