@@ -275,7 +275,7 @@ void LaunchConfigurationDialog::selectionChanged(QItemSelection selected, QItemS
             }
         }
     }
-    updateNameLabel(0);
+    updateNameLabel(nullptr);
 
     for( int i = 1; i < stack->count(); i++ )
     {
@@ -298,15 +298,16 @@ void LaunchConfigurationDialog::selectionChanged(QItemSelection selected, QItemS
             connect( l, &LaunchConfiguration::nameChanged, this, &LaunchConfigurationDialog::updateNameLabel );
             if( lm )
             {
-                bool b = debugger->blockSignals(true);
-                QList<ILauncher*> launchers = l->type()->launchers();
-                for( QList<ILauncher*>::const_iterator it = launchers.constBegin(); it != launchers.constEnd(); it++ )
                 {
-                    if( ((*it)->supportedModes().contains( lm->id() ) ) ) {
-                        debugger->addItem( (*it)->name(), (*it)->id() );
+                    QSignalBlocker blocker(debugger);
+                    QList<ILauncher*> launchers = l->type()->launchers();
+                    for( QList<ILauncher*>::const_iterator it = launchers.constBegin(); it != launchers.constEnd(); ++it )
+                    {
+                        if( ((*it)->supportedModes().contains( lm->id() ) ) ) {
+                            debugger->addItem( (*it)->name(), (*it)->id() );
+                        }
                     }
                 }
-                debugger->blockSignals(b);
 
                 debugger->setVisible(debugger->count()>0);
                 debugLabel->setVisible(debugger->count()>0);
@@ -560,7 +561,7 @@ LaunchConfigurationsModel::ProjectItem* LaunchConfigurationsModel::findItemForPr
         }
     }
     Q_ASSERT(false);
-    return 0;
+    return nullptr;
 }
 
 int LaunchConfigurationsModel::columnCount(const QModelIndex& parent) const
@@ -797,7 +798,7 @@ ILaunchMode* LaunchConfigurationsModel::modeForIndex( const QModelIndex& idx ) c
             return item->mode;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 LaunchConfiguration* LaunchConfigurationsModel::configForIndex(const QModelIndex& idx ) const
@@ -815,7 +816,7 @@ LaunchConfiguration* LaunchConfigurationsModel::configForIndex(const QModelIndex
             return dynamic_cast<LaunchItem*>( lmitem->parent )->launch;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 QModelIndex LaunchConfigurationsModel::indexForConfig( LaunchConfiguration* l ) const
@@ -872,7 +873,7 @@ void LaunchConfigurationsModel::createConfiguration(const QModelIndex& parent )
 
         LaunchConfigurationType* type = Core::self()->runController()->launchConfigurationTypes().at(0);
         QPair<QString,QString> launcher = qMakePair( type->launchers().at( 0 )->supportedModes().at(0), type->launchers().at( 0 )->id() );
-        IProject* p = ( ti ? ti->project : 0 );
+        IProject* p = ( ti ? ti->project : nullptr );
         ILaunchConfiguration* l = Core::self()->runController()->createLaunchConfiguration( type, launcher, p );
 
         addConfiguration(l, parent);
@@ -900,7 +901,7 @@ IProject* LaunchConfigurationsModel::projectForIndex(const QModelIndex& idx)
         return projectForIndex(idx.parent());
     } else {
         const ProjectItem* item = dynamic_cast<const ProjectItem*>(topItems[idx.row()]);
-        return item ? item->project : 0;
+        return item ? item->project : nullptr;
     }
 }
 
@@ -910,7 +911,7 @@ LaunchConfigPagesContainer::LaunchConfigPagesContainer( const QList<LaunchConfig
     setLayout( new QVBoxLayout( this ) );
     layout()->setContentsMargins( 0, 0, 0, 0 );
     QWidget* parentwidget = this;
-    QTabWidget* tab = 0;
+    QTabWidget* tab = nullptr;
     if( factories.count() > 1 )
     {
         tab = new QTabWidget( this );
@@ -962,7 +963,7 @@ QWidget* LaunchConfigurationModelDelegate::createEditor ( QWidget* parent, const
     {
         KComboBox* box = new KComboBox( parent );
         QList<ILauncher*> launchers = config->type()->launchers();
-        for( QList<ILauncher*>::const_iterator it = launchers.constBegin(); it != launchers.constEnd(); it++ )
+        for( QList<ILauncher*>::const_iterator it = launchers.constBegin(); it != launchers.constEnd(); ++it )
         {
             if( ((*it)->supportedModes().contains( mode->id() ) ) )
             {
@@ -974,7 +975,7 @@ QWidget* LaunchConfigurationModelDelegate::createEditor ( QWidget* parent, const
     {
         KComboBox* box = new KComboBox( parent );
         const QList<LaunchConfigurationType*> types = Core::self()->runController()->launchConfigurationTypes();
-        for( QList<LaunchConfigurationType*>::const_iterator it = types.begin(); it != types.end(); it++ )
+        for( QList<LaunchConfigurationType*>::const_iterator it = types.begin(); it != types.end(); ++it )
         {
             box->addItem( (*it)->name(), (*it)->id() );
         }
