@@ -67,7 +67,7 @@ public:
     enum ExtraRoles {
         DescriptionRole = Qt::UserRole+1
     };
-    PluginsModel(QObject* parent = 0)
+    PluginsModel(QObject* parent = nullptr)
         : QAbstractListModel(parent)
     {
         m_plugins = KDevelop::Core::self()->pluginControllerInternal()->loadedPlugins();
@@ -76,10 +76,10 @@ public:
 
     KDevelop::IPlugin *pluginForIndex(const QModelIndex& index) const
     {
-        if (!index.isValid()) return 0;
-        if (index.parent().isValid()) return 0;
-        if (index.column() != 0) return 0;
-        if (index.row() >= m_plugins.count()) return 0;
+        if (!index.isValid()) return nullptr;
+        if (index.parent().isValid()) return nullptr;
+        if (index.column() != 0) return nullptr;
+        if (index.row() >= m_plugins.count()) return nullptr;
         return m_plugins[index.row()];
     }
 
@@ -119,7 +119,7 @@ class LoadedPluginsDelegate : public KWidgetItemDelegate
 
 public:
 
-    LoadedPluginsDelegate(QAbstractItemView *itemView, QObject *parent = 0)
+    LoadedPluginsDelegate(QAbstractItemView *itemView, QObject *parent = nullptr)
         : KWidgetItemDelegate(itemView, parent)
         , pushButton(new QPushButton)
     {
@@ -131,11 +131,6 @@ public:
         delete pushButton;
     }
 
-    QList<QWidget *> createItemWidgets(const QModelIndex &/*index*/) const override
-    {
-        return QList<QWidget *>();
-    }
-
     QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override
     {
         int i = 5;
@@ -160,7 +155,7 @@ public:
 
         painter->save();
 
-        QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &option, painter, 0);
+        QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &option, painter, nullptr);
 
         int iconSize = option.rect.height() - MARGIN * 2;
         QIcon icon = QIcon::fromTheme(index.model()->data(index, Qt::DecorationRole).toString());
@@ -194,8 +189,10 @@ public:
         painter->restore();
     }
 
-    QList<QWidget*> createItemWidgets() const
+    QList<QWidget *> createItemWidgets(const QModelIndex &index) const override
     {
+        Q_UNUSED(index);
+
         QPushButton *button = new QPushButton();
         button->setIcon(QIcon::fromTheme(QStringLiteral("dialog-information")));
         setBlockedEventTypes(button, QList<QEvent::Type>() << QEvent::MouseButtonPress
@@ -242,13 +239,12 @@ private Q_SLOTS:
         PluginsModel *m = static_cast<PluginsModel*>(itemView()->model());
         KDevelop::IPlugin *p = m->pluginForIndex(focusedIndex());
         if (p) {
-//             TODO KF5: Port
-//             const K4AboutData *aboutData = p->componentData().aboutData();
-//             if (!aboutData->programName().isEmpty()) { // Be sure the about data is not completely empty
-//                 KAboutApplicationDialog aboutPlugin(aboutData, itemView());
-//                 aboutPlugin.exec();
-//                 return;
-//             }
+            KAboutData aboutData = KAboutData::fromPluginMetaData(pluginInfo(p));
+            if (!aboutData.componentName().isEmpty()) { // Be sure the about data is not completely empty
+                KAboutApplicationDialog aboutPlugin(aboutData, itemView());
+                aboutPlugin.exec();
+                return;
+            }
         }
     }
 private:
@@ -259,7 +255,7 @@ class PluginsView : public QListView
 {
     Q_OBJECT
 public:
-    PluginsView(QWidget* parent = 0)
+    PluginsView(QWidget* parent = nullptr)
         :QListView(parent)
     {
         setModel(new PluginsModel(this));
