@@ -554,7 +554,7 @@ IPlugin *PluginController::loadPluginInternal( const QString &pluginId )
         if (auto katePlugin = factory->create<KTextEditor::Plugin>(d->core, QVariantList() << info.pluginId())) {
             plugin = new KTextEditorIntegration::Plugin(katePlugin, d->core);
         } else {
-            qWarning() << "Creating plugin" << pluginId << "failed.";
+            qCWarning(SHELL) << "Creating plugin" << pluginId << "failed.";
             return nullptr;
         }
     }
@@ -562,7 +562,7 @@ IPlugin *PluginController::loadPluginInternal( const QString &pluginId )
     KConfigGroup group = Core::self()->activeSession()->config()->group(KEY_Plugins());
     // runtime errors such as missing executables on the system or such get checked now
     if (plugin->hasError()) {
-        qWarning() << "Could not load plugin" << pluginId << ", it reported the error:" << plugin->errorDescription()
+        qCWarning(SHELL) << "Could not load plugin" << pluginId << ", it reported the error:" << plugin->errorDescription()
                     << "Disabling the plugin now.";
         group.writeEntry(info.pluginId() + KEY_Suffix_Enabled(), false); // do the same as KPluginInfo did
         group.sync();
@@ -585,7 +585,7 @@ IPlugin* PluginController::plugin( const QString& pluginId )
 {
     KPluginMetaData info = infoForPluginId( pluginId );
     if ( !info.isValid() )
-        return 0L;
+        return nullptr;
 
     return d->loadedPlugins.value( info );
 }
@@ -685,19 +685,28 @@ QStringList PluginController::allPluginNames()
     return names;
 }
 
-QList<ContextMenuExtension> PluginController::queryPluginsForContextMenuExtensions( KDevelop::Context* context ) const
+QList<ContextMenuExtension> PluginController::queryPluginsForContextMenuExtensions(KDevelop::Context* context) const
 {
-    QList<ContextMenuExtension> exts;
-    for( auto it=d->loadedPlugins.constBegin(), itEnd = d->loadedPlugins.constEnd(); it!=itEnd; ++it )
-    {
-        IPlugin* plug = it.value();
-        exts << plug->contextMenuExtension( context );
+    // This fixes random order of extension menu items between different runs of KDevelop.
+    // Without sorting we have random reordering of "Analyze With" submenu for example:
+    // 1) "Cppcheck" actions, "Vera++" actions - first run
+    // 2) "Vera++" actions, "Cppcheck" actions - some other run.
+    QMultiMap<QString, IPlugin*> sortedPlugins;
+    for (auto it = d->loadedPlugins.constBegin(); it != d->loadedPlugins.constEnd(); ++it) {
+        sortedPlugins.insert(it.key().name(), it.value());
     }
-    exts << Core::self()->debugControllerInternal()->contextMenuExtension( context );
-    exts << Core::self()->documentationControllerInternal()->contextMenuExtension( context );
-    exts << Core::self()->sourceFormatterControllerInternal()->contextMenuExtension( context );
-    exts << Core::self()->runControllerInternal()->contextMenuExtension( context );
-    exts << Core::self()->projectControllerInternal()->contextMenuExtension( context );
+
+    QList<ContextMenuExtension> exts;
+    foreach (IPlugin* plugin, sortedPlugins) {
+        exts << plugin->contextMenuExtension(context);
+    }
+
+    exts << Core::self()->debugControllerInternal()->contextMenuExtension(context);
+    exts << Core::self()->documentationControllerInternal()->contextMenuExtension(context);
+    exts << Core::self()->sourceFormatterControllerInternal()->contextMenuExtension(context);
+    exts << Core::self()->runControllerInternal()->contextMenuExtension(context);
+    exts << Core::self()->projectControllerInternal()->contextMenuExtension(context);
+
     return exts;
 }
 
