@@ -94,7 +94,7 @@ public:
 
     Q_DECLARE_FLAGS(Features, FeatureCode)
 
-    explicit ProblemModel(QObject *parent, ProblemStore *store = NULL);
+    explicit ProblemModel(QObject *parent, ProblemStore *store = nullptr);
     ~ProblemModel() override;
 
     enum Columns {
@@ -129,21 +129,36 @@ public:
     /// Clears the problems
     void clearProblems();
 
+    /// Retrieve problems for selected document
+    QVector<IProblem::Ptr> problems(const KDevelop::IndexedString& document);
+
     /// Retrieve the supported features
     Features features() const;
 
+    /// Retrieve 'show imports' filter setting
+    bool showImports();
+
     /// Set the supported features
     void setFeatures(Features features);
 
+signals:
+    /// Emitted when the stored problems are changed with addProblem(), setProblems() and
+    /// clearProblems() methods. This signal emitted only when internal problems storage is
+    /// really changed: for example, it is not emitted when we call clearProblems() method
+    /// for empty model.
+    void problemsChanged();
+
 public slots:
     /// Show imports
-    virtual void setShowImports(bool){}
+    void setShowImports(bool showImports);
 
     /// Sets the scope filter. Uses int to be able to use QSignalMapper
-    virtual void setScope(int scope);
+    void setScope(int scope);
 
     /// Sets the severity filter. Uses int to be able to use QSignalMapper
-    virtual void setSeverity(int severity);
+    void setSeverity(int severity);///old-style severity filtering
+
+    void setSeverities(KDevelop::IProblem::Severities severities);///new-style severity filtering
 
     void setGrouping(int grouping);
 
@@ -162,6 +177,8 @@ private slots:
     /// Triggered when the current document changes
     virtual void setCurrentDocument(IDocument* doc);
 
+    virtual void closedDocument(IDocument* doc);
+
     /// Triggered before the problems are rebuilt
     void onBeginRebuild();
 
