@@ -67,8 +67,8 @@ class ProjectProgress : public QObject, public IStatus
 
     public:
         ProjectProgress();
-        virtual ~ProjectProgress();
-        virtual QString statusName() const override;
+        ~ProjectProgress() override;
+        QString statusName() const override;
 
         /*! Show indeterminate mode progress bar */
         void setBuzzy();
@@ -238,7 +238,7 @@ public:
 
         // developerfile == dirname(projectFileUrl) ."/.kdev4/". basename(projectfileUrl)
         developerFile = projectFile;
-        developerFile.setLastPathSegment( ".kdev4" );
+        developerFile.setLastPathSegment( QStringLiteral(".kdev4") );
         developerFile.addPath( projectFile.lastPathSegment() );
 
         statJob = KIO::stat( developerFile.toUrl(), KIO::HideProgressInfo );
@@ -313,7 +313,7 @@ public:
                                 i18n( "Could not load %1, a project with the same name '%2' is already open.",
                                 projectFile.pathOrUrl(), name ) );
 
-            qWarning() << "Trying to open a project with a name thats already used by another open project";
+            qWarning() << "Trying to open a project with a name that is already used by another open project";
             return true;
         }
         return false;
@@ -323,7 +323,7 @@ public:
     {
         if (manager)
         {
-            IProjectFileManager* iface = 0;
+            IProjectFileManager* iface = nullptr;
             iface = manager->extension<KDevelop::IProjectFileManager>();
             Q_ASSERT(iface);
             return iface;
@@ -334,24 +334,25 @@ public:
 
         //Get our importer
         IPluginController* pluginManager = Core::self()->pluginController();
-        manager = pluginManager->pluginForExtension( "org.kdevelop.IProjectFileManager", managerSetting );
-        IProjectFileManager* iface = 0;
+        manager = pluginManager->pluginForExtension( QStringLiteral("org.kdevelop.IProjectFileManager"), managerSetting );
+        IProjectFileManager* iface = nullptr;
         if ( manager )
             iface = manager->extension<IProjectFileManager>();
         else
         {
             KMessageBox::sorry( Core::self()->uiControllerInternal()->defaultMainWindow(),
-                            i18n( "Could not load project management plugin %1.",
+                            i18n( "Could not load project management plugin <b>%1</b>.<br> Check that the required programs are installed,"
+                                  " or see console output for more information.",
                                   managerSetting ) );
-            manager = 0;
-            return 0;
+            manager = nullptr;
+            return nullptr;
         }
-        if (iface == 0)
+        if (iface == nullptr)
         {
             KMessageBox::sorry( Core::self()->uiControllerInternal()->defaultMainWindow(),
                             i18n( "project importing plugin (%1) does not support the IProjectFileManager interface.", managerSetting ) );
             delete manager;
-            manager = 0;
+            manager = nullptr;
         }
         return iface;
     }
@@ -365,11 +366,12 @@ public:
             QString vcsPluginName = projectGroup.readEntry("VersionControlSupport", "");
             if( !vcsPluginName.isEmpty() )
             {
-                vcsPlugin = pluginManager->pluginForExtension( "org.kdevelop.IBasicVersionControl", vcsPluginName );
+                vcsPlugin = pluginManager->pluginForExtension( QStringLiteral( "org.kdevelop.IBasicVersionControl" ), vcsPluginName );
             }
         } else
         {
-            foreach( IPlugin* p, pluginManager->allPluginsForExtension( "org.kdevelop.IBasicVersionControl" ) )
+            QList<IPlugin*> plugins = pluginManager->allPluginsForExtension( QStringLiteral( "org.kdevelop.IBasicVersionControl" ) );
+            foreach( IPlugin* p, plugins )
             {
                 IBasicVersionControl* iface = p->extension<KDevelop::IBasicVersionControl>();
                 if( iface && iface->isVersionControlled( topItem->path().toUrl() ) )
@@ -406,11 +408,11 @@ Project::Project( QObject *parent )
         : IProject( parent )
         , d( new ProjectPrivate )
 {
-    QDBusConnection::sessionBus().registerObject( "/org/kdevelop/Project", this, QDBusConnection::ExportScriptableSlots );
+    QDBusConnection::sessionBus().registerObject( QStringLiteral("/org/kdevelop/Project"), this, QDBusConnection::ExportScriptableSlots );
 
     d->project = this;
-    d->manager = 0;
-    d->topItem = 0;
+    d->manager = nullptr;
+    d->topItem = nullptr;
     d->loading = false;
     d->scheduleReload = false;
     d->progress = new ProjectProgress;
@@ -460,7 +462,7 @@ void Project::reloadModel()
     // delete topItem and remove it from model
     ProjectModel* model = Core::self()->projectController()->projectModel();
     model->removeRow( d->topItem->row() );
-    d->topItem = 0;
+    d->topItem = nullptr;
 
     IProjectFileManager* iface = d->manager->extension<IProjectFileManager>();
     if (!d->importTopItem(iface))
