@@ -124,17 +124,16 @@ SourceFormatterController::SourceFormatterController(QObject *parent)
     m_formatFilesAction->setWhatsThis(i18n("Formatting functionality using <b>astyle</b> library."));
     connect(m_formatFilesAction, &QAction::triggered, this, static_cast<void(SourceFormatterController::*)()>(&SourceFormatterController::formatFiles));
 
-    // connect to both documentActivated & documentClosed,
-    // otherwise we miss when the last document was closed
+    m_formatTextAction->setEnabled(false);
+    m_formatFilesAction->setEnabled(true);
+
     connect(Core::self()->documentController(), &IDocumentController::documentActivated,
-            this, &SourceFormatterController::updateFormatTextAction);
-    connect(Core::self()->documentController(), &IDocumentController::documentClosed,
-            this, &SourceFormatterController::updateFormatTextAction);
+            this, &SourceFormatterController::activeDocumentChanged);
     // Use a queued connection, because otherwise the view is not yet fully set up
     connect(Core::self()->documentController(), &IDocumentController::documentLoaded,
             this, &SourceFormatterController::documentLoaded, Qt::QueuedConnection);
 
-    updateFormatTextAction();
+    activeDocumentChanged(Core::self()->documentController()->activeDocument());
 }
 
 void SourceFormatterController::documentLoaded( IDocument* doc )
@@ -189,8 +188,8 @@ ISourceFormatter* SourceFormatterController::findFirstFormatterForMimeType(const
             return iformatter;
         }
     }
-    knownFormatters[mime.name()] = 0;
-    return 0;
+    knownFormatters[mime.name()] = nullptr;
+    return nullptr;
 }
 
 static void populateStyleFromConfigGroup(SourceFormatterStyle* s, const KConfigGroup& stylegrp)
@@ -226,7 +225,7 @@ SourceFormatter* SourceFormatterController::createFormatterForPlugin(ISourceForm
 ISourceFormatter* SourceFormatterController::formatterForMimeType(const QMimeType& mime)
 {
     if( !m_enabled || !isMimeTypeSupported( mime ) ) {
-        return 0;
+        return nullptr;
     }
     QString formatter = sessionConfig().readEntry( mime.name(), QString() );
 
@@ -239,7 +238,7 @@ ISourceFormatter* SourceFormatterController::formatterForMimeType(const QMimeTyp
 
     if( formatterinfo.size() != 2 ) {
         qCDebug(SHELL) << "Broken formatting entry for mime:" << mime.name() << "current value:" << formatter;
-        return 0;
+        return nullptr;
     }
 
     return Core::self()->pluginControllerInternal()->extensionForPlugin<ISourceFormatter>( QStringLiteral("org.kdevelop.ISourceFormatter"), formatterinfo.at(0) );
@@ -340,26 +339,23 @@ void SourceFormatterController::cleanup()
 {
 }
 
-void SourceFormatterController::updateFormatTextAction()
+
+void SourceFormatterController::activeDocumentChanged(IDocument* doc)
 {
     bool enabled = false;
 
-    IDocument* doc = KDevelop::ICore::self()->documentController()->activeDocument();
     if (doc) {
         QMimeType mime = QMimeDatabase().mimeTypeForUrl(doc->url());
         if (isMimeTypeSupported(mime))
             enabled = true;
     }
 
-    m_formatLine->setEnabled(enabled);
     m_formatTextAction->setEnabled(enabled);
 }
 
 void SourceFormatterController::beautifySource()
 {
     IDocument* idoc = KDevelop::ICore::self()->documentController()->activeDocument();
-    if (!idoc)
-        return;
     KTextEditor::View* view = idoc->activeTextView();
     if (!view)
         return;
@@ -436,11 +432,6 @@ void SourceFormatterController::beautifyLine()
 
 void SourceFormatterController::formatDocument(KDevelop::IDocument* doc, ISourceFormatter* formatter, const QMimeType& mime)
 {
-    Q_ASSERT(doc);
-    Q_ASSERT(formatter);
-
-    qCDebug(SHELL) << "Running" << formatter->name() << "on" << doc->url();
-
     // We don't use KTextEditor::Document directly, because CodeRepresentation transparently works
     // around a possible tab-replacement incompatibility between kate and kdevelop
     CodeRepresentation::Ptr code = KDevelop::createCodeRepresentation( IndexedString( doc->url() ) );
@@ -585,14 +576,14 @@ void SourceFormatterController::formatFiles(QList<QUrl> &list)
         qCDebug(SHELL) << "Processing file " << list[fileCount] << endl;
         KIO::StoredTransferJob *job = KIO::storedGet(list[fileCount]);
         if (job->exec()) {
-            QString text = QString::fromLocal8Bit(job->data());
-            text = formatter->formatSource(text, list[fileCount], mime);
-            text = addModelineForCurrentLang(text, list[fileCount], mime).toUtf8();
-            job = KIO::storedPut(text.toLocal8Bit(), list[fileCount], -1, KIO::Overwrite);
+            QByteArray data = job->data();
+            QString output = formatter->formatSource(data, list[fileCount], mime);
+            data += addModelineForCurrentLang(output, list[fileCount], mime).toUtf8();
+            job = KIO::storedPut(data, list[fileCount], -1);
             if (!job->exec())
-                KMessageBox::error(0, job->errorString());
+                KMessageBox::error(nullptr, job->errorString());
         } else
-            KMessageBox::error(0, job->errorString());
+            KMessageBox::error(nullptr, job->errorString());
     }
 }
 
