@@ -69,13 +69,11 @@ public:
     FakeFileManager(QObject*, const QVariantList&)
         : IPlugin(ICore::self()->aboutData().componentName(), Core::self())
     {
-        KDEV_USE_EXTENSION_INTERFACE( KDevelop::IProjectFileManager )
     }
 
     FakeFileManager()
         : IPlugin(ICore::self()->aboutData().componentName(), Core::self())
     {
-        KDEV_USE_EXTENSION_INTERFACE( KDevelop::IProjectFileManager )
     }
 
     ~FakeFileManager() override {}
@@ -126,8 +124,8 @@ public:
         return it;
     }
 
-    ProjectFolderItem* addFolder(const Path& /*folder*/, ProjectFolderItem */*parent*/) override { return 0; }
-    ProjectFileItem* addFile(const Path& /*file*/, ProjectFolderItem */*parent*/) override { return 0; }
+    ProjectFolderItem* addFolder(const Path& /*folder*/, ProjectFolderItem */*parent*/) override { return nullptr; }
+    ProjectFileItem* addFile(const Path& /*file*/, ProjectFolderItem */*parent*/) override { return nullptr; }
     bool removeFilesAndFolders(const QList<ProjectBaseItem*> &/*items*/) override { return false; }
     bool moveFilesAndFolders(const QList< KDevelop::ProjectBaseItem* > &/*items*/, KDevelop::ProjectFolderItem* /*newParent*/) override { return false; }
     bool copyFilesAndFolders(const Path::List &/*items*/, KDevelop::ProjectFolderItem* /*newParent*/) override { return false; }
@@ -148,8 +146,9 @@ public:
 
     IPlugin* pluginForExtension(const QString& extension, const QString& pluginName = {}, const QVariantMap& constraints = QVariantMap()) override
     {
-        if (extension == m_fakeFileManager->extensions().at(0))
+        if (extension == qobject_interface_iid<IProjectFileManager*>()) {
             return m_fakeFileManager;
+        }
         return PluginController::pluginForExtension(extension, pluginName, constraints);
     }
 
@@ -161,7 +160,7 @@ private:
 
 void TestProjectController::initTestCase()
 {
-    AutoTestShell::init({{}});
+    AutoTestShell::init();
     TestCore* testCore = new TestCore;
     testCore->setPluginController( new FakePluginController(testCore) );
     testCore->initialize();
@@ -535,7 +534,7 @@ void TestProjectController::assertSpyCaughtProject(QSignalSpy* spy, IProject* pr
 void TestProjectController::assertProjectClosed(IProject* proj)
 {
     IProject* p = m_projCtrl->findProjectByName(proj->name());
-    QVERIFY(p == 0);
+    QVERIFY(p == nullptr);
     QVERIFY(!m_projCtrl->projects().contains(proj));
 }
 
