@@ -60,6 +60,8 @@
 #include "settings/sourceformattersettings.h"
 #include "settings/uipreferences.h"
 #include "settings/templateconfig.h"
+#include "settings/analyzerspreferences.h"
+#include "settings/documentationpreferences.h"
 
 namespace KDevelop {
 
@@ -119,7 +121,7 @@ public:
         }
         else
         {
-            activeSublimeWindow = defaultMainWindow = 0;
+            activeSublimeWindow = defaultMainWindow = nullptr;
         }
 
         m_assistantTimer.setSingleShot(true);
@@ -158,7 +160,7 @@ class UiToolViewFactory: public Sublime::ToolFactory {
 public:
     UiToolViewFactory(IToolViewFactory *factory): m_factory(factory) {}
     ~UiToolViewFactory() override { delete m_factory; }
-    QWidget* create(Sublime::ToolDocument *doc, QWidget *parent = 0) override
+    QWidget* create(Sublime::ToolDocument *doc, QWidget *parent = nullptr) override
     {
         Q_UNUSED( doc );
         return m_factory->create(parent);
@@ -182,7 +184,7 @@ private:
 
 class ViewSelectorItem: public QListWidgetItem {
 public:
-    ViewSelectorItem(const QString &text, QListWidget *parent = 0, int type = Type)
+    ViewSelectorItem(const QString &text, QListWidget *parent = nullptr, int type = Type)
         :QListWidgetItem(text, parent, type) {}
     IToolViewFactory *factory;
 };
@@ -192,7 +194,7 @@ class NewToolViewListWidget: public QListWidget {
     Q_OBJECT
 
 public:
-    NewToolViewListWidget(MainWindow *mw, QWidget* parent = 0)
+    NewToolViewListWidget(MainWindow *mw, QWidget* parent = nullptr)
         :QListWidget(parent), m_mw(mw)
     {
         connect(this, &NewToolViewListWidget::doubleClicked, this, &NewToolViewListWidget::addNewToolViewByDoubleClick);
@@ -215,7 +217,7 @@ private:
 };
 
 UiController::UiController(Core *core)
-    :Sublime::Controller(0), IUiController(), d(new UiControllerPrivate(this))
+    :Sublime::Controller(nullptr), IUiController(), d(new UiControllerPrivate(this))
 {
     setObjectName(QStringLiteral("UiController"));
     d->core = core;
@@ -277,7 +279,7 @@ void UiController::switchToArea(const QString &areaName, SwitchMode switchMode)
 QWidget* UiController::findToolView(const QString& name, IToolViewFactory *factory, FindFlags flags)
 {
     if(!d->areasRestored || !activeArea())
-        return 0;
+        return nullptr;
 
     QList< Sublime::View* > views = activeArea()->toolViews();
     foreach(Sublime::View* view, views) {
@@ -289,7 +291,7 @@ QWidget* UiController::findToolView(const QString& name, IToolViewFactory *facto
         }
     }
 
-    QWidget* ret = 0;
+    QWidget* ret = nullptr;
 
     if(flags & Create)
     {
@@ -405,7 +407,7 @@ Sublime::Area *UiController::activeArea()
     Sublime::MainWindow *m = activeSublimeWindow();
     if (m)
         return activeSublimeWindow()->area();
-    return 0;
+    return nullptr;
 }
 
 Sublime::MainWindow *UiController::activeSublimeWindow()
@@ -491,27 +493,37 @@ void UiController::addNewToolView(MainWindow *mw, QListWidgetItem* item)
 
 void UiController::showSettingsDialog()
 {
-    auto editorConfigPage = new EditorConfigPage(activeMainWindow());
-    auto languageConfigPage = new LanguagePreferences(activeMainWindow());
+    auto parent = activeMainWindow();
+
+    auto editorConfigPage = new EditorConfigPage(parent);
+    auto languageConfigPage = new LanguagePreferences(parent);
+    auto analyzersPreferences = new AnalyzersPreferences(parent);
+    auto documentationPreferences = new DocumentationPreferences(parent);
 
     auto configPages = QVector<KDevelop::ConfigPage*> {
-        new UiPreferences(activeMainWindow()),
-        new PluginPreferences(activeMainWindow()),
-        new SourceFormatterSettings(activeMainWindow()),
-        new ProjectPreferences(activeMainWindow()),
-        new EnvironmentPreferences(QString(), activeMainWindow()),
-        new BGPreferences(activeMainWindow()),
-        new TemplateConfig(activeMainWindow()),
+        new UiPreferences(parent),
+        new PluginPreferences(parent),
+        new SourceFormatterSettings(parent),
+        new ProjectPreferences(parent),
+        new EnvironmentPreferences(QString(), parent),
+        new TemplateConfig(parent),
         editorConfigPage
     };
 
-    ConfigDialog cfgDlg(configPages, activeMainWindow());
+    ConfigDialog cfgDlg(configPages, parent);
 
     auto addPluginPages = [&](IPlugin* plugin) {
         for (int i = 0, numPages = plugin->configPages(); i < numPages; ++i) {
             auto page = plugin->configPage(i, &cfgDlg);
-            if(page && page->configPageType() == ConfigPage::LanguageConfigPage){
+            if (!page)
+                continue;
+
+            if (page->configPageType() == ConfigPage::LanguageConfigPage) {
                 cfgDlg.addSubConfigPage(languageConfigPage, page);
+            } else if (page->configPageType() == ConfigPage::AnalyzerConfigPage) {
+                cfgDlg.addSubConfigPage(analyzersPreferences, page);
+            } else if (page->configPageType() == ConfigPage::DocumentationConfigPage) {
+                cfgDlg.addSubConfigPage(documentationPreferences, page);
             } else {
                 // insert them before the editor config page
                 cfgDlg.addConfigPage(page, editorConfigPage);
@@ -519,11 +531,16 @@ void UiController::showSettingsDialog()
         }
     };
 
-    cfgDlg.addConfigPage(languageConfigPage, configPages[5]);
+    cfgDlg.addConfigPage(documentationPreferences, configPages[5]);
+    cfgDlg.addConfigPage(analyzersPreferences, documentationPreferences);
+
+    cfgDlg.addConfigPage(languageConfigPage, analyzersPreferences);
+    cfgDlg.addSubConfigPage(languageConfigPage, new BGPreferences(parent));
 
     foreach (IPlugin* plugin, ICore::self()->pluginController()->loadedPlugins()) {
         addPluginPages(plugin);
     }
+
     // TODO: only load settings if a UI related page was changed?
     connect(&cfgDlg, &ConfigDialog::configSaved, activeSublimeWindow(), &Sublime::MainWindow::loadSettings);
     // make sure that pages get added whenever a new plugin is loaded (probably from the plugin selection dialog)
@@ -668,7 +685,7 @@ void UiController::addToolViewToDockArea(IToolViewFactory* factory, Qt::DockWidg
 
 bool UiController::toolViewPresent(Sublime::ToolDocument* doc, Sublime::Area* area)
 {
-    foreach (Sublime::View *view, doc->views()) {
+    for (Sublime::View *view : doc->views()) {
         if( area->toolViews().contains( view ) )
             return true;
     }
