@@ -169,8 +169,27 @@ struct ContainerPrivate {
 
         std::sort(views.begin(), views.end(), sortViews);
 
-        foreach(View* view, views) {
-            QAction* action = documentListMenu->addAction(view->document()->title());
+        for (int i = 0; i < views.size(); ++i) {
+            View *view = views.at(i);
+            QString visibleEntryTitle;
+            // if filename is not unique, prepend containing directory
+            if ((i < views.size() - 1 && view->document()->title() == views.at(i + 1)->document()->title())
+                || (i > 0 && view->document()->title() == views.at(i - 1)->document()->title())
+            ) {
+                auto urlDoc = qobject_cast<Sublime::UrlDocument*>(view->document());
+                if (!urlDoc) {
+                    visibleEntryTitle = view->document()->title();
+                }
+                else {
+                    auto url = urlDoc->url().toString();
+                    int secondOffset = url.lastIndexOf('/');
+                    secondOffset = url.lastIndexOf('/', secondOffset - 1);
+                    visibleEntryTitle = url.right(url.length() - url.lastIndexOf('/', secondOffset) - 1);
+                }
+            } else {
+                visibleEntryTitle = view->document()->title();
+            }
+            QAction* action = documentListMenu->addAction(visibleEntryTitle);
             action->setData(QVariant::fromValue(view));
             documentListActionForView[view] = action;
             action->setIcon(view->document()->icon());
@@ -183,7 +202,7 @@ struct ContainerPrivate {
 class UnderlinedLabel: public KSqueezedTextLabel {
 Q_OBJECT
 public:
-    UnderlinedLabel(QTabBar *tabBar, QWidget* parent = 0)
+    UnderlinedLabel(QTabBar *tabBar, QWidget* parent = nullptr)
         :KSqueezedTextLabel(parent), m_tabBar(tabBar)
     {
     }
@@ -230,7 +249,7 @@ protected:
 class StatusLabel: public UnderlinedLabel {
 Q_OBJECT
 public:
-    StatusLabel(QTabBar *tabBar, QWidget* parent = 0):
+    StatusLabel(QTabBar *tabBar, QWidget* parent = nullptr):
         UnderlinedLabel(tabBar, parent)
     {
         setAlignment(Qt::AlignRight | Qt::AlignVCenter);
@@ -310,7 +329,7 @@ void Container::setLeftCornerWidget(QWidget* widget)
 {
     if(d->leftCornerWidget.data() == widget) {
         if(d->leftCornerWidget)
-            d->leftCornerWidget.data()->setParent(0);
+            d->leftCornerWidget.data()->setParent(nullptr);
     }else{
         delete d->leftCornerWidget.data();
         d->leftCornerWidget.clear();
@@ -419,13 +438,11 @@ void Container::documentTitleChanged(Sublime::Document* doc)
             if (tabIndex != -1) {
                 d->tabBar->setTabText(tabIndex, doc->title());
             }
-
-            // Update document list popup title
-            Q_ASSERT(d->documentListActionForView.contains(view));
-            d->documentListActionForView[view]->setText(doc->title());
             break;
         }
     }
+    // Update document list popup title
+    d->updateDocumentListPopupMenu();
 }
 
 int Container::count() const
@@ -444,9 +461,10 @@ void Container::setCurrentWidget(QWidget* w)
     //prevent from emitting activateView() signal on tabbar active tab change
     //this function is called from MainWindow::activateView()
     //which does the activation without any additional signals
-    d->tabBar->blockSignals(true);
-    d->tabBar->setCurrentIndex(d->stack->indexOf(w));
-    d->tabBar->blockSignals(false);
+    {
+        QSignalBlocker blocker(d->tabBar);
+        d->tabBar->setCurrentIndex(d->stack->indexOf(w));
+    }
     if (View* view = viewForWidget(w))
     {
         statusChanged(view);
