@@ -27,8 +27,13 @@
 #include <QHash>
 
 class IdealToolButton;
+class ToolViewAction;
 class QAction;
-namespace Sublime {
+
+class KConfigGroup;
+
+namespace Sublime
+{
 
 class MainWindow;
 class IdealController;
@@ -44,8 +49,10 @@ public:
     IdealButtonBarWidget(Qt::DockWidgetArea area,
         IdealController *controller, Sublime::MainWindow *parent);
 
-    QAction* addWidget(const QString& title, IdealDockWidget *widget,
+    QAction* addWidget(IdealDockWidget *widget,
                        Area* area, View *view);
+
+    void addAction(QAction *action);
     void removeAction(QAction* action);
 
     Qt::Orientation orientation() const;
@@ -59,6 +66,13 @@ public:
     void showWidget(QAction *widgetAction, bool checked);
     bool isEmpty();
 
+    bool isShown();
+    void saveShowState();
+    bool lastShowState();
+
+    void loadOrderSettings(const KConfigGroup& configGroup);
+    void saveOrderSettings(KConfigGroup& configGroup);
+
 private Q_SLOTS:
     void showWidget(bool checked);
     void buttonPressed(bool state);
@@ -66,15 +80,20 @@ private Q_SLOTS:
 signals:
     void emptyChanged();
 
-protected:
-    void actionEvent(QActionEvent *event) override;
-
 private:
+    void applyOrderToLayout();
+    void takeOrderFromLayout();
+
+    IdealToolButton* button(const QString& id) const;
+    QString id(const IdealToolButton* button) const;
+
+    void addButtonToOrder(const IdealToolButton* button);
+
     Qt::DockWidgetArea _area;
     IdealController *_controller;
-    QHash<QAction *, IdealToolButton*> _buttons;
-    QHash<QAction *, IdealDockWidget*> _widgets;
     QWidget *_corner;
+    bool _showState;
+    QStringList _buttonsOrder;
 };
 
 }
