@@ -91,7 +91,7 @@ void IdealController::addView(Qt::DockWidgetArea area, View* view)
 
     KAcceleratorManager::setNoAccel(dock);
     QWidget *w = view->widget(dock);
-    if (w->parent() == 0)
+    if (w->parent() == nullptr)
     {
         /* Could happen when we're moving the widget from
            one IdealDockWidget to another.  See moveView below.
@@ -123,9 +123,7 @@ void IdealController::addView(Qt::DockWidgetArea area, View* view)
     dock->setFocusProxy(dock->widget());
 
     if (IdealButtonBarWidget* bar = barForDockArea(area)) {
-        QAction* action = bar->addWidget(
-            view->document()->title(), dock,
-            static_cast<MainWindow*>(parent())->area(), view);
+        QAction* action = bar->addWidget(dock, static_cast<MainWindow*>(parent())->area(), view);
         m_dockwidget_to_action[dock] = m_view_to_action[view] = action;
 
         m_docks->addAction(action);
@@ -167,9 +165,7 @@ void IdealController::dockLocationChanged(Qt::DockWidgetArea area)
     docks.insert(dock);
 
     if (IdealButtonBarWidget* bar = barForDockArea(area)) {
-        QAction* action = bar->addWidget(
-            view->document()->title(), dock,
-            static_cast<MainWindow*>(parent())->area(), view);
+        QAction* action = bar->addWidget(dock, static_cast<MainWindow*>(parent())->area(), view);
         m_dockwidget_to_action[dock] = m_view_to_action[view] = action;
 
         // at this point the dockwidget is visible (user dragged it)
@@ -212,7 +208,7 @@ IdealButtonBarWidget* IdealController::barForDockArea(Qt::DockWidgetArea area) c
 
         default:
             Q_ASSERT(false);
-            return 0;
+            return nullptr;
     }
 }
 
@@ -299,9 +295,8 @@ void IdealController::setShowDockStatus(Qt::DockWidgetArea area, bool checked)
 {
     QAction* action = actionForArea(area);
     if (action->isChecked() != checked) {
-        bool blocked = action->blockSignals(true);
+        QSignalBlocker blocker(action);
         action->setChecked(checked);
-        action->blockSignals(blocked);
     }
 }
 
@@ -347,7 +342,7 @@ void IdealController::removeView(View* view, bool nondestructive)
     m_dockwidget_to_action.remove(dock);
 
     if (nondestructive)
-        view->widget()->setParent(0);
+        view->widget()->setParent(nullptr);
 
     delete dock;
 }
@@ -393,9 +388,8 @@ void IdealController::showDock(Qt::DockWidgetArea area, bool show)
         // re-sync action state given we may have asked for the dock to be hidden
         QAction* action = actionForArea(area);
         if (!action->isChecked()) {
-            action->blockSignals(true);
+            QSignalBlocker blocker(action);
             action->setChecked(true);
-            action->blockSignals(false);
         }
         return;
     }
@@ -429,7 +423,7 @@ IdealDockWidget* IdealController::currentDockWidget()
 
         w = w->parentWidget();
     }
-    return 0;
+    return nullptr;
 }
 
 void IdealController::goPrevNextDock(IdealController::Direction direction)
@@ -499,11 +493,6 @@ void IdealController::loadSettings()
         m_mainWindow->setCorner(Qt::BottomRightCorner, Qt::RightDockWidgetArea);
 }
 
-void IdealController::setWidthForArea(Qt::DockWidgetArea area, int width)
-{
-    m_widthsForAreas[area] = width;
-}
-
 void IdealController::emitWidgetResized(Qt::DockWidgetArea dockArea, int thickness)
 {
     emit widgetResized(dockArea, thickness);
