@@ -21,6 +21,7 @@
 #include <QLayout>
 #include <QSplitter>
 #include <QTimer>
+#include <QApplication>
 #include <QToolBar>
 
 #include <KActionMenu>
@@ -45,10 +46,8 @@ class IdealToolBar : public QToolBar
     public:
         explicit IdealToolBar(const QString& title, bool hideWhenEmpty, Sublime::IdealButtonBarWidget* buttons, QMainWindow* parent)
             : QToolBar(title, parent)
-            , m_timer(nullptr)
             , m_buttons(buttons)
             , m_hideWhenEmpty(hideWhenEmpty)
-            , m_requestedVisibility(true)
         {
             setMovable(false);
             setFloatable(false);
@@ -58,43 +57,26 @@ class IdealToolBar : public QToolBar
             addWidget(m_buttons);
 
             if (m_hideWhenEmpty) {
-                m_timer = new QTimer(this);
-                m_timer->setInterval(100);
-                m_timer->setSingleShot(true);
-                connect(m_timer, &QTimer::timeout, this, &IdealToolBar::refresh);
-                connect(this, &IdealToolBar::visibilityChanged, m_timer, static_cast<void(QTimer::*)()>(&QTimer::start));
-                connect(m_buttons, &Sublime::IdealButtonBarWidget::emptyChanged, m_timer, static_cast<void(QTimer::*)()>(&QTimer::start));
-            }
-        }
-
-        void setVisible(bool visible) override
-        {
-            QToolBar::setVisible(visible);
-
-            m_requestedVisibility = visible;
-
-            if (m_hideWhenEmpty && visible) {
-                m_timer->start();
+                connect(m_buttons, &Sublime::IdealButtonBarWidget::emptyChanged,
+                        this, &IdealToolBar::updateVisibilty);
             }
         }
 
     private slots:
-        void refresh()
+        void updateVisibilty()
         {
-            setVisible(m_requestedVisibility && !m_buttons->isEmpty());
+            setVisible(!m_buttons->isEmpty());
         }
 
     private:
-        QTimer* m_timer;
         Sublime::IdealButtonBarWidget* m_buttons;
         const bool m_hideWhenEmpty;
-        bool m_requestedVisibility;
 };
 
 namespace Sublime {
 
 MainWindowPrivate::MainWindowPrivate(MainWindow *w, Controller* controller)
-:controller(controller), area(0), activeView(0), activeToolView(0), bgCentralWidget(0),
+:controller(controller), area(nullptr), activeView(nullptr), activeToolView(nullptr), bgCentralWidget(nullptr),
  ignoreDockShown(false), autoAreaSettingsSave(false), m_mainWindow(w)
 {
     KActionCollection *ac = m_mainWindow->actionCollection();
@@ -184,7 +166,7 @@ MainWindowPrivate::MainWindowPrivate(MainWindow *w, Controller* controller)
             this,
             &MainWindowPrivate::widgetResized);
 
-   connect(idealController, &IdealController::dockBarContextMenuRequested,
+    connect(idealController, &IdealController::dockBarContextMenuRequested,
             m_mainWindow, &MainWindow::dockBarContextMenuRequested);
 }
 
@@ -220,10 +202,6 @@ void MainWindowPrivate::restoreConcentrationMode()
     m_bottomToolBar->setVisible(!concentrationModeOn);
     m_leftToolBar->setVisible(!concentrationModeOn);
     m_rightToolBar->setVisible(!concentrationModeOn);
-    const bool hideToolBar = concentrationModeOn || !Container::configTabBarVisible();
-    foreach(Container* c, viewContainers) {
-        c->setTabBarHidden(hideToolBar);
-    }
 
     if (concentrationModeOn) {
         m_concentrateToolBar = new QToolBar(m_mainWindow);
@@ -236,7 +214,7 @@ void MainWindowPrivate::restoreConcentrationMode()
         m_concentrateToolBar->setMovable(false);
 
         m_mainWindow->addToolBar(Qt::TopToolBarArea, m_concentrateToolBar);
-        m_mainWindow->menuBar()->setCornerWidget(0, Qt::TopRightCorner);
+        m_mainWindow->menuBar()->setCornerWidget(nullptr, Qt::TopRightCorner);
     } else if (cornerWidget) {
         m_mainWindow->menuBar()->setCornerWidget(cornerWidget, Qt::TopRightCorner);
         cornerWidget->show();
@@ -253,9 +231,12 @@ bool MainWindowPrivate::eventFilter(QObject* obj, QEvent* event)
 {
     Q_ASSERT(m_mainWindow == obj);
     if (event->type() == QEvent::KeyPress || event->type() == QEvent::KeyRelease) {
-        Qt::KeyboardModifiers modifiers = static_cast<QKeyEvent *>(event)->modifiers();
+        const auto ev = static_cast<QKeyEvent *>(event);
+        Qt::KeyboardModifiers modifiers = ev->modifiers();
 
-        m_mainWindow->menuBar()->setVisible(modifiers == Qt::AltModifier && event->type() == QEvent::KeyPress);
+        //QLineEdit banned mostly so that alt navigation can be used from QuickOpen
+        const bool visible = modifiers == Qt::AltModifier && ev->type() == QEvent::KeyPress && !qApp->focusWidget()->inherits("QLineEdit");
+        m_mainWindow->menuBar()->setVisible(visible);
     }
 
     return false;
@@ -365,14 +346,14 @@ Area::WalkerMode MainWindowPrivate::ViewCreator::operator() (AreaIndex *index)
         splitter->setOrientation(index->orientation());
     else
     {
-        Container *container = 0;
+        Container *container = nullptr;
 
         while(splitter->count() && qobject_cast<QSplitter*>(splitter->widget(0)))
         {
             // After unsplitting, we might have to remove old splitters
             QWidget* widget = splitter->widget(0);
             qCDebug(SUBLIME) << "deleting" << widget;
-            widget->setParent(0);
+            widget->setParent(nullptr);
             delete widget;
         }
 
@@ -438,32 +419,28 @@ void MainWindowPrivate::reconstruct()
 {
     if(m_leftTabbarCornerWidget) {
         m_leftTabbarCornerWidget->hide();
-        m_leftTabbarCornerWidget->setParent(0);
+        m_leftTabbarCornerWidget->setParent(nullptr);
     }
 
-    idealController->setWidthForArea(Qt::LeftDockWidgetArea, area->thickness(Sublime::Left));
-    idealController->setWidthForArea(Qt::BottomDockWidgetArea, area->thickness(Sublime::Bottom));
-    idealController->setWidthForArea(Qt::RightDockWidgetArea, area->thickness(Sublime::Right));
-
     IdealToolViewCreator toolViewCreator(this);
     area->walkToolViews(toolViewCreator, Sublime::AllPositions);
 
     reconstructViews();
 
-    m_mainWindow->blockSignals(true);
-
-    qCDebug(SUBLIME) << "RECONSTRUCT" << area << area->shownToolViews(Sublime::Left);
-    foreach (View *view, area->toolViews())
     {
-        QString id = view->document()->documentSpecifier();
-        if (!id.isEmpty())
+        QSignalBlocker blocker(m_mainWindow);
+        qCDebug(SUBLIME) << "RECONSTRUCT" << area << area->shownToolViews(Sublime::Left);
+        foreach (View *view, area->toolViews())
         {
-            Sublime::Position pos = area->toolViewPosition(view);
-            if (area->shownToolViews(pos).contains(id))
-                idealController->raiseView(view, IdealController::GroupWithOtherViews);
+            QString id = view->document()->documentSpecifier();
+            if (!id.isEmpty())
+            {
+                Sublime::Position pos = area->toolViewPosition(view);
+                if (area->shownToolViews(pos).contains(id))
+                    idealController->raiseView(view, IdealController::GroupWithOtherViews);
+            }
         }
     }
-    m_mainWindow->blockSignals(false);
 
     setTabBarLeftCornerWidget(m_leftTabbarCornerWidget.data());
 }
@@ -471,7 +448,7 @@ void MainWindowPrivate::reconstruct()
 void MainWindowPrivate::clearArea()
 {
     if(m_leftTabbarCornerWidget)
-        m_leftTabbarCornerWidget->setParent(0);
+        m_leftTabbarCornerWidget->setParent(nullptr);
 
     //reparent toolview widgets to 0 to prevent their deletion together with dockwidgets
     foreach (View *view, area->toolViews())
@@ -481,7 +458,7 @@ void MainWindowPrivate::clearArea()
         idealController->removeView(view, nonDestructive);
 
         if (view->hasWidget())
-            view->widget()->setParent(0);
+            view->widget()->setParent(nullptr);
     }
 
     docks.clear();
@@ -491,12 +468,12 @@ void MainWindowPrivate::clearArea()
     foreach (View *view, area->views())
     {
         if (view->hasWidget())
-            view->widget()->setParent(0);
+            view->widget()->setParent(nullptr);
     }
     cleanCentralWidget();
-    m_mainWindow->setActiveView(0);
+    m_mainWindow->setActiveView(nullptr);
     m_indexSplitters.clear();
-    area = 0;
+    area = nullptr;
     viewContainers.clear();
 
     setTabBarLeftCornerWidget(m_leftTabbarCornerWidget.data());
@@ -547,7 +524,7 @@ void MainWindowPrivate::viewAdded(Sublime::AreaIndex *index, Sublime::View *view
 {
     if(m_leftTabbarCornerWidget) {
         m_leftTabbarCornerWidget->hide();
-        m_leftTabbarCornerWidget->setParent(0);
+        m_leftTabbarCornerWidget->setParent(nullptr);
     }
 
     // Remove container objects in the hierarchy from the parents,
@@ -569,7 +546,7 @@ void MainWindowPrivate::viewAdded(Sublime::AreaIndex *index, Sublime::View *view
                 {
                     while (container->count())
                     {
-                        container->widget(0)->setParent(0);
+                        container->widget(0)->setParent(nullptr);
                     }
                     //and then delete the container
                     delete container;
@@ -621,7 +598,7 @@ void MainWindowPrivate::aboutToRemoveView(Sublime::AreaIndex *index, Sublime::Vi
         //just remove a widget
         if( view->widget() ) {
             container->removeWidget(view->widget());
-            view->widget()->setParent(0);
+            view->widget()->setParent(nullptr);
             //activate what is visible currently in the container if the removed view was active
             if (wasActive)
                 return m_mainWindow->setActiveView(container->viewForWidget(container->currentWidget()));
@@ -631,7 +608,7 @@ void MainWindowPrivate::aboutToRemoveView(Sublime::AreaIndex *index, Sublime::Vi
     {
         if(m_leftTabbarCornerWidget) {
             m_leftTabbarCornerWidget->hide();
-            m_leftTabbarCornerWidget->setParent(0);
+            m_leftTabbarCornerWidget->setParent(nullptr);
         }
 
         // We've about to remove the last view of this container.  It will
@@ -643,7 +620,7 @@ void MainWindowPrivate::aboutToRemoveView(Sublime::AreaIndex *index, Sublime::Vi
         container->removeWidget(view->widget());
 
         if (view->widget())
-            view->widget()->setParent(0);
+            view->widget()->setParent(nullptr);
         else
             qWarning() << "View does not have a widget!";
 
@@ -651,7 +628,7 @@ void MainWindowPrivate::aboutToRemoveView(Sublime::AreaIndex *index, Sublime::Vi
         // We can be called from signal handler of container
         // (which is tab widget), so defer deleting it.
         container->deleteLater();
-        container->setParent(0);
+        container->setParent(nullptr);
 
         /* If we're not at the top level, we get to collapse split views.  */
         if (index->parent())
@@ -659,7 +636,7 @@ void MainWindowPrivate::aboutToRemoveView(Sublime::AreaIndex *index, Sublime::Vi
             /* The splitter used to have container as the only child, now it's
                time to get rid of it.  Make sure deleting splitter does not
                delete container -- per above comment, we'll delete it later.  */
-            container->setParent(0);
+            container->setParent(nullptr);
             m_indexSplitters.remove(index);
             delete splitter;
 
@@ -710,7 +687,7 @@ void MainWindowPrivate::aboutToRemoveView(Sublime::AreaIndex *index, Sublime::Vi
 
     setTabBarLeftCornerWidget(m_leftTabbarCornerWidget.data());
     if ( wasActive ) {
-        m_mainWindow->setActiveView(0L);
+        m_mainWindow->setActiveView(nullptr);
     }
 }
 
@@ -805,11 +782,11 @@ void MainWindowPrivate::setTabBarLeftCornerWidget(QWidget* widget)
 
 //     Q_ASSERT(splitter || putToIndex == area->rootIndex());
 
-    Container* c = 0;
+    Container* c = nullptr;
     if(splitter) {
         c = qobject_cast<Container*>(splitter->widget(0));
     }else{
-        c = viewContainers.values()[0];
+        c = *viewContainers.constBegin();
     }
     Q_ASSERT(c);
 
