@@ -18,9 +18,7 @@
  ***************************************************************************/
 #include "view.h"
 
-#include <QtGui/QWidget>
-
-#include <kdebug.h>
+#include <QWidget>
 
 #include "document.h"
 #include "tooldocument.h"
@@ -40,13 +38,13 @@ struct ViewPrivate
 };
 
 ViewPrivate::ViewPrivate()
-    :doc(0), widget(0)
+    :doc(nullptr), widget(nullptr)
 {
 }
 
 void ViewPrivate::unsetWidget()
 {
-    widget = 0;
+    widget = nullptr;
 }
 
 View::View(Document *doc, WidgetOwnership ws )
@@ -60,7 +58,7 @@ View::~View()
 {
     if (d->widget && d->ws == View::TakeOwnership ) {
         d->widget->hide();
-        d->widget->setParent(0);
+        d->widget->setParent(nullptr);
         d->widget->deleteLater();
     }
     delete d;
@@ -76,7 +74,7 @@ QWidget *View::widget(QWidget *parent)
     if (!d->widget)
     {
         d->widget = createWidget(parent);
-        connect(d->widget, SIGNAL(destroyed()), this, SLOT(unsetWidget()));
+        connect(d->widget, &QWidget::destroyed, this, [&] { d->unsetWidget(); });
     }
     return d->widget;
 }
@@ -88,7 +86,7 @@ QWidget *View::createWidget(QWidget *parent)
 
 bool View::hasWidget() const
 {
-    return d->widget != 0;
+    return d->widget != nullptr;
 }
 
 void View::requestRaise()
@@ -138,4 +136,4 @@ void View::notifyPositionChanged(int newPositionInArea)
 
 }
 
-#include "view.moc"
+#include "moc_view.cpp"
