@@ -27,7 +27,9 @@
 
 #include "dvcsplugin.h"
 
-#include <QtGui/QMenu>
+#include <QMenu>
+#include <QDialog>
+#include <QVBoxLayout>
 #include <QtCore/QFileInfo>
 #include <QtCore/QString>
 
@@ -44,12 +46,14 @@
 #include <interfaces/idocumentcontroller.h>
 
 #include "dvcsjob.h"
-#include "ui/importmetadatawidget.h"
+#include "ui/dvcsimportmetadatawidget.h"
 #include "ui/branchmanager.h"
 #include "ui/revhistory/commitlogmodel.h"
 #include "ui/revhistory/commitView.h"
 #include <vcs/vcspluginhelper.h>
 
+#include <KConfigGroup>
+
 namespace KDevelop
 {
 
@@ -62,8 +66,8 @@ struct DistributedVersionControlPluginPrivate {
 };
 
 //class DistributedVersionControlPlugin
-DistributedVersionControlPlugin::DistributedVersionControlPlugin(QObject *parent, KComponentData compData)
-        : IPlugin(compData, parent)
+DistributedVersionControlPlugin::DistributedVersionControlPlugin(QObject *parent, const QString& componentName)
+        : IPlugin(componentName, parent)
         , d(new DistributedVersionControlPluginPrivate(this))
 {}
 
@@ -84,17 +88,17 @@ DistributedVersionControlPlugin::~DistributedVersionControlPlugin()
 KDevelop::VcsImportMetadataWidget*
 DistributedVersionControlPlugin::createImportMetadataWidget(QWidget* parent)
 {
-    return new ImportMetadataWidget(parent);
+    return new DvcsImportMetadataWidget(parent);
 }
 
 KDevelop::ContextMenuExtension
 DistributedVersionControlPlugin::contextMenuExtension(Context* context)
 {
     d->m_common->setupFromContext(context);
-    KUrl::List const & ctxUrlList = d->m_common->contextUrlList();
+    QList<QUrl> const & ctxUrlList = d->m_common->contextUrlList();
 
     bool isWorkingDirectory = false;
-    foreach(const KUrl &url, ctxUrlList) {
+    foreach(const QUrl &url, ctxUrlList) {
         if (isValidDirectory(url)) {
             isWorkingDirectory = true;
             break;
@@ -118,17 +122,18 @@ DistributedVersionControlPlugin::contextMenuExtension(Context* context)
 
 }
 
-void DistributedVersionControlPlugin::additionalMenuEntries(QMenu* /*menu*/, const KUrl::List& /*urls*/)
+void DistributedVersionControlPlugin::additionalMenuEntries(QMenu* /*menu*/, const QList<QUrl>& /*urls*/)
 {}
 
 static QString stripPathToDir(const QString &path)
 {
-    return QFileInfo(path).absolutePath();
+    QFileInfo info = QFileInfo(path);
+    return info.isDir() ? info.absoluteFilePath() : info.absolutePath();
 }
 
 void DistributedVersionControlPlugin::ctxBranchManager()
 {
-    KUrl::List const & ctxUrlList = d->m_common->contextUrlList();
+    QList<QUrl> const & ctxUrlList = d->m_common->contextUrlList();
     Q_ASSERT(!ctxUrlList.isEmpty());    
     
     ICore::self()->documentController()->saveAllDocuments();
@@ -141,17 +146,24 @@ void DistributedVersionControlPlugin::ctxBranchManager()
 // This is redundant with the normal VCS "history" action
 void DistributedVersionControlPlugin::ctxRevHistory()
 {
-    KUrl::List const & ctxUrlList = d->m_common->contextUrlList();
+    QList<QUrl> const & ctxUrlList = d->m_common->contextUrlList();
     Q_ASSERT(!ctxUrlList.isEmpty());
     
-    KDialog d;
+    QDialog d;
+    QVBoxLayout* layout = new QVBoxLayout(&d);
+    d.setLayout(layout);
 
     CommitLogModel* model = new CommitLogModel(this, ctxUrlList.first().toLocalFile(), &d);
     CommitView *revTree = new CommitView(&d);
     revTree->setModel(model);
+    layout->addWidget(revTree);
+
+    QDialogButtonBox* dbox = new QDialogButtonBox(&d);
+    dbox->setStandardButtons(QDialogButtonBox::Close);
+    connect(dbox, &QDialogButtonBox::accepted, &d, &QDialog::accept);
+    connect(dbox, &QDialogButtonBox::rejected, &d, &QDialog::reject);
+    layout->addWidget(dbox);
 
-    d.setButtons(KDialog::Close);
-    d.setMainWidget(revTree);
     d.exec();
 }
 
