@@ -29,11 +29,10 @@
 #include <QBrush>
 #include <QPen>
 #include <QHash>
+#include <QLocale>
+#include <QUrl>
 
-#include <kurl.h>
-#include <klocale.h>
-#include <kglobal.h>
-#include <kdebug.h>
+#include <KLocalizedString>
 
 #include <interfaces/icore.h>
 #include <interfaces/iruncontroller.h>
@@ -77,7 +76,7 @@ public:
     }
 };
 
-VcsAnnotationModel::VcsAnnotationModel(VcsJob *job, const KUrl& url, QObject* parent,
+VcsAnnotationModel::VcsAnnotationModel(VcsJob *job, const QUrl& url, QObject* parent,
                                        const QColor &foreground, const QColor &background)
     : d( new VcsAnnotationModelPrivate( this ) )
     , foreground(foreground)
@@ -87,7 +86,7 @@ VcsAnnotationModel::VcsAnnotationModel(VcsJob *job, const KUrl& url, QObject* pa
     d->m_annotation.setLocation( url );
     d->job = job;
     qsrand( QDateTime().toTime_t() );
-    connect( d->job, SIGNAL(resultsReady(KDevelop::VcsJob*)),SLOT(addLines(KDevelop::VcsJob*)) );
+    connect( d->job, &VcsJob::resultsReady,this, [&] (VcsJob* job) { d->addLines(job); } );
     ICore::self()->runController()->registerJob( d->job );
 }
 
@@ -99,7 +98,7 @@ VcsAnnotationModel::~VcsAnnotationModel()
 static QString abbreviateLastName(const QString& author) {
     auto parts = author.split(' ');
     bool onlyOneFragment = parts.size() == 1 || ( parts.size() == 2 && parts.at(1).isEmpty() );
-    return onlyOneFragment ? parts.first() : parts.first() + QString(" %1.").arg(parts.last()[0]);
+    return onlyOneFragment ? parts.first() : parts.first() + QStringLiteral(" %1.").arg(parts.last()[0]);
 }
 
 QVariant VcsAnnotationModel::data( int line, Qt::ItemDataRole role ) const
@@ -119,14 +118,14 @@ QVariant VcsAnnotationModel::data( int line, Qt::ItemDataRole role ) const
         return QVariant( d->m_brushes[aline.revision()] );
     } else if( role == Qt::DisplayRole )
     {
-        return QVariant( QString("%1 ").arg(aline.date().date().year()) + abbreviateLastName(aline.author()) );
+        return QVariant( QStringLiteral("%1 ").arg(aline.date().date().year()) + abbreviateLastName(aline.author()) );
     } else if( role == Qt::UserRole ) // TODO KDE5: replace by KTextEditor::AnnotationModel::GroupIdentifierRole
     {
         return aline.revision().revisionValue();
     } else if( role == Qt::ToolTipRole )
     {
         return QVariant( i18n("Author: %1\nDate: %2\nCommit Message: %3",
-                              aline.author(), KGlobal::locale()->formatDateTime( aline.date() ), aline.commitMessage() ) );
+                              aline.author(), QLocale().toString( aline.date() ), aline.commitMessage() ) );
     }
     return QVariant();
 }
@@ -145,4 +144,4 @@ VcsRevision VcsAnnotationModel::revisionForLine( int line ) const
 
 }
 
-#include "vcsannotationmodel.moc"
+#include "moc_vcsannotationmodel.cpp"
