@@ -55,7 +55,6 @@
 #include "vcsstatusinfo.h"
 #include "vcsevent.h"
 #include "widgets/vcsdiffpatchsources.h"
-#include "widgets/flexibleaction.h"
 
 namespace KDevelop
 {
@@ -395,39 +394,15 @@ void VcsPluginHelper::annotation()
                     SIGNAL(annotationContextMenuAboutToShow(KTextEditor::View*,QMenu*,int)),
                     this, SLOT(annotationContextMenuAboutToShow(KTextEditor::View*,QMenu*,int)));
         } else {
-            KMessageBox::error(0, i18n("Cannot display annotations, missing interface KTextEditor::AnnotationInterface for the editor."));
+            KMessageBox::error(nullptr, i18n("Cannot display annotations, missing interface KTextEditor::AnnotationInterface for the editor."));
             delete job;
         }
     } else {
-        KMessageBox::error(0, i18n("Cannot execute annotate action because the "
+        KMessageBox::error(nullptr, i18n("Cannot execute annotate action because the "
                                    "document was not found, or was not a text document:\n%1", url.toDisplayString(QUrl::PreferLocalFile)));
     }
 }
 
-class CopyFunction : public AbstractFunction
-{
-    public:
-        CopyFunction(const QString& tocopy)
-            : m_tocopy(tocopy) {}
-
-        void operator()() override { QApplication::clipboard()->setText(m_tocopy); }
-    private:
-        QString m_tocopy;
-};
-
-class HistoryFunction : public AbstractFunction
-{
-    public:
-        HistoryFunction(VcsPluginHelper* helper, const VcsRevision& rev)
-            : m_helper(helper), m_rev(rev) {}
-
-            void operator()() override { m_helper->history(m_rev); }
-
-    private:
-        VcsPluginHelper* m_helper;
-        VcsRevision m_rev;
-};
-
 void VcsPluginHelper::annotationContextMenuAboutToShow( KTextEditor::View* view, QMenu* menu, int line )
 {
     KTextEditor::AnnotationInterface* annotateiface =
@@ -448,8 +423,15 @@ void VcsPluginHelper::annotationContextMenuAboutToShow( KTextEditor::View* view,
     menu->addSeparator();
     menu->addAction(d->diffForRevAction);
     menu->addAction(d->diffForRevGlobalAction);
-    menu->addAction(new FlexibleAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy Revision"), new CopyFunction(rev.revisionValue().toString()), menu));
-    menu->addAction(new FlexibleAction(QIcon::fromTheme(QStringLiteral("view-history")), i18n("History..."), new HistoryFunction(this, rev), menu));
+    QAction* action = nullptr;
+    action = menu->addAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy Revision"));
+    connect(action, &QAction::triggered, this, [this, rev]() {
+        QApplication::clipboard()->setText(rev.revisionValue().toString());
+    });
+    action = menu->addAction(QIcon::fromTheme(QStringLiteral("view-history")), i18n("History..."));
+    connect(action, &QAction::triggered, this, [this, rev]() {
+        history(rev);
+    });
 }
 
 void VcsPluginHelper::update()
